@@ -22,12 +22,15 @@ from twisted.internet import defer
 from twisted.python import log
 from twisted.web import client
 
+from buildbot import config
 from buildbot.changes import base
 from buildbot.util import bytes2unicode
 from buildbot.util import datetime2epoch
 from buildbot.util import deferredLocked
 from buildbot.util import epoch2datetime
 
+_UNSPECIFIED = object()
+
 
 class BitbucketPullrequestPoller(base.PollingChangeSource):
 
@@ -44,15 +47,17 @@ class BitbucketPullrequestPoller(base.PollingChangeSource):
                  category=None,
                  project='',
                  pullrequest_filter=True,
-                 encoding='utf-8',
+                 encoding=_UNSPECIFIED,
                  pollAtLaunch=False
                  ):
 
         self.owner = owner
         self.slug = slug
         self.branch = branch
-        super().__init__(name='/'.join([owner, slug]), pollInterval=pollInterval, pollAtLaunch=pollAtLaunch)
-        self.encoding = encoding
+        super().__init__(name='/'.join([owner, slug]), pollInterval=pollInterval,
+                         pollAtLaunch=pollAtLaunch)
+        if encoding != _UNSPECIFIED:
+            config.warnDeprecated('2.6.0', 'encoding of BitbucketPullrequestPoller is deprecated.')
 
         if hasattr(pullrequest_filter, '__call__'):
             self.pullrequest_filter = pullrequest_filter
@@ -69,8 +74,7 @@ class BitbucketPullrequestPoller(base.PollingChangeSource):
 
     def describe(self):
         return "BitbucketPullrequestPoller watching the "\
-            "Bitbucket repository %s/%s, branch: %s" % (
-                self.owner, self.slug, self.branch)
+            "Bitbucket repository {}/{}, branch: {}".format(self.owner, self.slug, self.branch)
 
     @deferredLocked('initLock')
     def poll(self):
@@ -82,14 +86,14 @@ class BitbucketPullrequestPoller(base.PollingChangeSource):
     def _getChanges(self):
         self.lastPoll = time.time()
         log.msg("BitbucketPullrequestPoller: polling "
-                "Bitbucket repository %s/%s, branch: %s" % (self.owner, self.slug, self.branch))
-        url = "https://bitbucket.org/api/2.0/repositories/%s/%s/pullrequests" % (
-            self.owner, self.slug)
+                "Bitbucket repository {}/{}, branch: {}".format(self.owner, self.slug, self.branch))
+        url = "https://bitbucket.org/api/2.0/repositories/{}/{}/pullrequests".format(self.owner,
+                                                                                     self.slug)
         return client.getPage(url, timeout=self.pollInterval)
 
     @defer.inlineCallbacks
     def _processChanges(self, page):
-        result = json.loads(page, encoding=self.encoding)
+        result = json.loads(page)
         for pr in result['values']:
             branch = pr['source']['branch']['name']
             nr = int(pr['id'])
@@ -106,7 +110,7 @@ class BitbucketPullrequestPoller(base.PollingChangeSource):
                 if not current or current[0:12] != revision[0:12]:
                     # parse pull request api page (required for the filter)
                     page = yield client.getPage(str(pr['links']['self']['href']))
-                    pr_json = json.loads(page, encoding=self.encoding)
+                    pr_json = json.loads(page)
 
                     # filter pull requests by user function
                     if not self.pullrequest_filter(pr_json):
@@ -126,14 +130,16 @@ class BitbucketPullrequestPoller(base.PollingChangeSource):
                         updated = epoch2datetime(self.master.reactor.seconds())
                     title = pr['title']
                     # parse commit api page
-                    page = yield client.getPage(str(pr['source']['commit']['links']['self']['href']))
-                    commit_json = json.loads(page, encoding=self.encoding)
+                    page = yield client.getPage(
+                            str(pr['source']['commit']['links']['self']['href']))
+                    commit_json = json.loads(page)
                     # use the full-length hash from now on
                     revision = commit_json['hash']
                     revlink = commit_json['links']['html']['href']
                     # parse repo api page
-                    page = yield client.getPage(str(pr['source']['repository']['links']['self']['href']))
-                    repo_json = json.loads(page, encoding=self.encoding)
+                    page = yield client.getPage(
+                            str(pr['source']['repository']['links']['self']['href']))
+                    repo_json = json.loads(page)
                     repo = repo_json['links']['html']['href']
 
                     # update database
@@ -144,8 +150,7 @@ class BitbucketPullrequestPoller(base.PollingChangeSource):
                         committer=None,
                         revision=bytes2unicode(revision),
                         revlink=bytes2unicode(revlink),
-                        comments='pull-request #%d: %s\n%s' % (
-                            nr, title, prlink),
+                        comments='pull-request #{}: {}\n{}'.format(nr, title, prlink),
                         when_timestamp=datetime2epoch(updated),
                         branch=bytes2unicode(branch),
                         category=self.category,
@@ -190,4 +195,4 @@ class BitbucketPullrequestPoller(base.PollingChangeSource):
     def _getStateObjectId(self):
         # Return a deferred for object id in state db.
         return self.master.db.state.getObjectId(
-            '%s/%s#%s' % (self.owner, self.slug, self.branch), self.db_class_name)
+            '{}/{}#{}'.format(self.owner, self.slug, self.branch), self.db_class_name)
