@@ -13,12 +13,9 @@
 #
 # Copyright Buildbot Team Members
 
-from future.utils import text_type
-
 import copy
 
 from twisted.internet import defer
-from twisted.internet import reactor
 from twisted.python import log
 
 from buildbot.data import base
@@ -43,6 +40,9 @@ class FixerMixin:
             change['sourcestamp'] = yield self.master.data.get(sskey)
             del change['sourcestampid']
         return change
+    fieldMapping = {
+        'changeid': 'changes.changeid',
+    }
 
 
 class ChangeEndpoint(FixerMixin, base.Endpoint):
@@ -81,13 +81,9 @@ class ChangesEndpoint(FixerMixin, base.Endpoint):
             else:
                 changes = []
         else:
-            # this special case is useful and implemented by the dbapi
-            # so give it a boost
-            if (resultSpec.order == ('-changeid',) and resultSpec.limit and
-                    resultSpec.offset is None):
-                changes = yield self.master.db.changes.getRecentChanges(resultSpec.limit)
-            else:
-                changes = yield self.master.db.changes.getChanges()
+            if resultSpec is not None:
+                resultSpec.fieldMapping = self.fieldMapping
+                changes = yield self.master.db.changes.getChanges(resultSpec=resultSpec)
         results = []
         for ch in changes:
             results.append((yield self._fixChange(ch)))
@@ -107,6 +103,7 @@ class Change(base.ResourceType):
         changeid = types.Integer()
         parent_changeids = types.List(of=types.Integer())
         author = types.String()
+        committer = types.String()
         files = types.List(of=types.String())
         comments = types.String()
         revision = types.NoneOk(types.String())
@@ -123,10 +120,10 @@ class Change(base.ResourceType):
 
     @base.updateMethod
     @defer.inlineCallbacks
-    def addChange(self, files=None, comments=None, author=None, revision=None,
+    def addChange(self, files=None, comments=None, author=None, committer=None, revision=None,
                   when_timestamp=None, branch=None, category=None, revlink='',
                   properties=None, repository='', codebase=None, project='',
-                  src=None, _reactor=reactor):
+                  src=None):
         metrics.MetricCountEvent.log("added_changes", 1)
 
         if properties is None:
@@ -149,6 +146,7 @@ class Change(base.ResourceType):
 
         if callable(category):
             pre_change = self.master.config.preChangeGenerator(author=author,
+                                                               committer=committer,
                                                                files=files,
                                                                comments=comments,
                                                                revision=revision,
@@ -164,6 +162,7 @@ class Change(base.ResourceType):
         if codebase is None \
                 and self.master.config.codebaseGenerator is not None:
             pre_change = self.master.config.preChangeGenerator(author=author,
+                                                               committer=committer,
                                                                files=files,
                                                                comments=comments,
                                                                revision=revision,
@@ -175,13 +174,14 @@ class Change(base.ResourceType):
                                                                repository=repository,
                                                                project=project)
             codebase = self.master.config.codebaseGenerator(pre_change)
-            codebase = text_type(codebase)
+            codebase = str(codebase)
         else:
             codebase = codebase or ''
 
         # add the Change to the database
         changeid = yield self.master.db.changes.addChange(
             author=author,
+            committer=committer,
             files=files,
             comments=comments,
             revision=revision,
@@ -193,8 +193,7 @@ class Change(base.ResourceType):
             repository=repository,
             codebase=codebase,
             project=project,
-            uid=uid,
-            _reactor=_reactor)
+            uid=uid)
 
         # get the change and munge the result for the notification
         change = yield self.master.data.get(('changes', str(changeid)))
@@ -202,7 +201,7 @@ class Change(base.ResourceType):
         self.produceEvent(change, 'new')
 
         # log, being careful to handle funny characters
-        msg = "added change with revision %s to database" % (revision,)
+        msg = "added change with revision {} to database".format(revision)
         log.msg(msg.encode('utf-8', 'replace'))
 
         return changeid
