@@ -151,8 +151,8 @@ def get_sqlalchemy_migrate_version():
     return tuple(map(int, version.split('.')))
 
 
-class BuildbotEngineStrategy(strategies.ThreadLocalEngineStrategy):
-    # A subclass of the ThreadLocalEngineStrategy that can effectively interact
+class BuildbotEngineStrategy(strategies.PlainEngineStrategy):
+    # A subclass of the PlainEngineStrategy that can effectively interact
     # with Buildbot.
     #
     # This adjusts the passed-in parameters to ensure that we get the behaviors
@@ -208,7 +208,7 @@ class BuildbotEngineStrategy(strategies.ThreadLocalEngineStrategy):
         # default to the MyISAM storage engine
         storage_engine = u.query.pop('storage_engine', 'MyISAM')
         kwargs['connect_args'] = {
-            'init_command': 'SET default_storage_engine=%s' % storage_engine,
+            'init_command': 'SET default_storage_engine={}'.format(storage_engine)
         }
 
         if 'use_unicode' in u.query:
@@ -236,12 +236,13 @@ class BuildbotEngineStrategy(strategies.ThreadLocalEngineStrategy):
             return  # unparseable -- oh well
 
         if version_tup < (0, 6):
-            raise RuntimeError("SQLAlchemy version %s is too old" % (version,))
+            raise RuntimeError("SQLAlchemy version {} is too old".format(version))
         if version_tup > (0, 7, 10):
             mvt = get_sqlalchemy_migrate_version()
             if mvt < (0, 8, 0):
-                raise RuntimeError("SQLAlchemy version %s is not supported by "
-                                   "SQLAlchemy-Migrate version %d.%d.%d" % (version, mvt[0], mvt[1], mvt[2]))
+                raise RuntimeError(("SQLAlchemy version {} is not supported by "
+                                    "SQLAlchemy-Migrate version {}.{}.{}").format(version, mvt[0],
+                                                                                  mvt[1], mvt[2]))
 
     def get_drivers_strategy(self, drivername):
         if drivername.startswith('sqlite'):
