@@ -96,7 +96,7 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
         self.initLock = defer.DeferredLock()
 
         # set up child services
-        self.create_child_services()
+        self._services_d = self.create_child_services()
 
         # db configured values
         self.configured_db_url = None
@@ -125,70 +125,70 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
             self.hostname = socket.getfqdn()
 
         # public attributes
-        self.name = ("%s:%s" % (self.hostname,
-                                os.path.abspath(self.basedir or '.')))
+        self.name = ("{}:{}".format(self.hostname, os.path.abspath(self.basedir or '.')))
         if isinstance(self.name, bytes):
             self.name = self.name.decode('ascii', 'replace')
         self.masterid = None
 
+    @defer.inlineCallbacks
     def create_child_services(self):
         # note that these are order-dependent.  If you get the order wrong,
         # you'll know it, as the master will fail to start.
 
         self.metrics = metrics.MetricLogObserver()
-        self.metrics.setServiceParent(self)
+        yield self.metrics.setServiceParent(self)
 
         self.caches = cache.CacheManager()
-        self.caches.setServiceParent(self)
+        yield self.caches.setServiceParent(self)
 
         self.pbmanager = buildbot.pbmanager.PBManager()
-        self.pbmanager.setServiceParent(self)
+        yield self.pbmanager.setServiceParent(self)
 
         self.workers = workermanager.WorkerManager(self)
-        self.workers.setServiceParent(self)
+        yield self.workers.setServiceParent(self)
 
         self.change_svc = ChangeManager()
-        self.change_svc.setServiceParent(self)
+        yield self.change_svc.setServiceParent(self)
 
         self.botmaster = BotMaster()
-        self.botmaster.setServiceParent(self)
+        yield self.botmaster.setServiceParent(self)
 
         self.machine_manager = MachineManager()
-        self.machine_manager.setServiceParent(self)
+        yield self.machine_manager.setServiceParent(self)
 
         self.scheduler_manager = SchedulerManager()
-        self.scheduler_manager.setServiceParent(self)
+        yield self.scheduler_manager.setServiceParent(self)
 
         self.user_manager = UserManagerManager(self)
-        self.user_manager.setServiceParent(self)
+        yield self.user_manager.setServiceParent(self)
 
         self.db = dbconnector.DBConnector(self.basedir)
-        self.db.setServiceParent(self)
+        yield self.db.setServiceParent(self)
 
         self.wamp = wampconnector.WampConnector()
-        self.wamp.setServiceParent(self)
+        yield self.wamp.setServiceParent(self)
 
         self.mq = mqconnector.MQConnector()
-        self.mq.setServiceParent(self)
+        yield self.mq.setServiceParent(self)
 
         self.data = dataconnector.DataConnector()
-        self.data.setServiceParent(self)
+        yield self.data.setServiceParent(self)
 
         self.www = wwwservice.WWWService()
-        self.www.setServiceParent(self)
+        yield self.www.setServiceParent(self)
 
         self.debug = debug.DebugServices()
-        self.debug.setServiceParent(self)
+        yield self.debug.setServiceParent(self)
 
         self.status = Status()
-        self.status.setServiceParent(self)
+        yield self.status.setServiceParent(self)
 
         self.secrets_manager = SecretManager()
-        self.secrets_manager.setServiceParent(self)
+        yield self.secrets_manager.setServiceParent(self)
         self.secrets_manager.reconfig_priority = 2000
 
         self.service_manager = service.BuildbotServiceManager()
-        self.service_manager.setServiceParent(self)
+        yield self.service_manager.setServiceParent(self)
         self.service_manager.reconfig_priority = 1000
 
         self.masterHouskeepingTimer = 0
@@ -213,8 +213,13 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
         assert not self._already_started, "can only start the master once"
         self._already_started = True
 
-        log.msg("Starting BuildMaster -- buildbot.version: %s" %
-                buildbot.version)
+        # ensure child services have been set up. Normally we would do this in serServiceParent,
+        # but buildmaster is used in contexts we can't control.
+        if self._services_d is not None:
+            yield self._services_d
+            self._services_d = None
+
+        log.msg("Starting BuildMaster -- buildbot.version: {}".format(buildbot.version))
 
         # Set umask
         if self.umask is not None:
@@ -261,7 +266,7 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
                 self.reactor.stop()
                 return
 
-            self.mq.setup()
+            yield self.mq.setup()
 
             if hasattr(signal, "SIGHUP"):
                 def sighup(*args):
@@ -357,9 +362,9 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
 
         # notify every 10 seconds that the reconfig is still going on, although
         # reconfigs should not take that long!
-        self.reconfig_notifier = task.LoopingCall(lambda:
-                                                  log.msg("reconfig is ongoing for %d s" %
-                                                          (self.reactor.seconds() - self.reconfig_active)))
+        self.reconfig_notifier = task.LoopingCall(
+            lambda: log.msg("reconfig is ongoing for {} s".format(self.reactor.seconds() -
+                                                                  self.reconfig_active)))
         self.reconfig_notifier.start(10, now=False)
 
         timer = metrics.Timer("BuildMaster.reconfig")
