@@ -226,7 +226,7 @@ class BasicBuildChooser(BuildChooserBase):
                     nextBreq = None
             except Exception:
                 log.err(Failure(),
-                        "from _getNextUnclaimedBuildRequest for builder '%s'" % (self.bldr,))
+                        "from _getNextUnclaimedBuildRequest for builder '{}'".format(self.bldr))
                 nextBreq = None
         else:
             # otherwise just return the first build
@@ -247,7 +247,7 @@ class BasicBuildChooser(BuildChooserBase):
                 worker = yield self.nextWorker(self.bldr, self.workerpool, buildrequest)
             except Exception:
                 log.err(Failure(),
-                        "from nextWorker for builder '%s'" % (self.bldr,))
+                        "from nextWorker for builder '{}'".format(self.bldr))
                 worker = None
 
             if not worker or worker not in self.workerpool:
@@ -364,10 +364,11 @@ class BuildRequestDistributor(service.AsyncMultiService):
                     self._activity_loop_deferred = self._activityLoop()
             except Exception:  # pragma: no cover
                 log.err(Failure(),
-                        "while attempting to start builds on %s" % self.name)
+                        "while attempting to start builds on {}".format(self.name))
 
         yield self.pending_builders_lock.run(
             resetPendingBuildersList, new_builders)
+        return None
 
     @defer.inlineCallbacks
     def _defaultSorter(self, master, builders):
@@ -476,8 +477,7 @@ class BuildRequestDistributor(service.AsyncMultiService):
                 if bldr:
                     yield self._maybeStartBuildsOnBuilder(bldr)
             except Exception:
-                log.err(Failure(),
-                        "from maybeStartBuild for builder '%s'" % (bldr_name,))
+                log.err(Failure(), "from maybeStartBuild for builder '{}'".format(bldr_name))
 
             self.activity_lock.release()
 
