@@ -124,7 +124,7 @@ class MessageFormatter(MessageFormatterBase):
         elif results == EXCEPTION:
             text = "build exception"
         else:
-            text = "%s build" % (statusToString(results))
+            text = "{} build".format(statusToString(results))
 
         return text
 
@@ -147,7 +147,7 @@ class MessageFormatter(MessageFormatterBase):
             source = ""
 
             if ss['branch']:
-                source += "[branch %s] " % ss['branch']
+                source += "[branch {}] ".format(ss['branch'])
 
             if ss['revision']:
                 source += str(ss['revision'])
@@ -159,9 +159,9 @@ class MessageFormatter(MessageFormatterBase):
 
             discriminator = ""
             if ss['codebase']:
-                discriminator = " '%s'" % ss['codebase']
+                discriminator = " '{}'".format(ss['codebase'])
 
-            text += "Build Source Stamp%s: %s\n" % (discriminator, source)
+            text += "Build Source Stamp{}: {}\n".format(discriminator, source)
 
         return text
 
@@ -175,16 +175,17 @@ class MessageFormatter(MessageFormatterBase):
         if results == SUCCESS:
             text = "Build succeeded!"
         elif results == WARNINGS:
-            text = "Build Had Warnings%s" % (t,)
+            text = "Build Had Warnings{}".format(t)
         elif results == CANCELLED:
             text = "Build was cancelled"
         else:
-            text = "BUILD FAILED%s" % (t,)
+            text = "BUILD FAILED{}".format(t)
 
         return text
 
     @defer.inlineCallbacks
-    def formatMessageForBuildResults(self, mode, buildername, buildset, build, master, previous_results, blamelist):
+    def formatMessageForBuildResults(self, mode, buildername, buildset, build, master,
+                                     previous_results, blamelist):
         """Generate a buildbot mail message and return a dictionary
            containing the message body, type and subject."""
         ss_list = buildset['sourcestamps']
