@@ -116,16 +116,16 @@ class BaseParameter:
         """
 
         if name in ["owner", "builderNames", "builderid"]:
-            config.error(
-                "%s cannot be used as a parameter name, because it is reserved" % (name,))
+            config.error("{} cannot be used as a parameter name, because it is reserved".format(
+                    name))
         self.name = name
         self.label = name if label is None else label
         self.tablabel = self.label if tablabel is None else tablabel
         if regex:
             self.regex = re.compile(regex)
         if 'value' in kw:
-            config.error("Use default='%s' instead of value=... to give a "
-                         "default Parameter value" % kw['value'])
+            config.error(("Use default='{}' instead of value=... to give a "
+                          "default Parameter value").format(kw['value']))
         # all other properties are generically passed via **kw
         self.__dict__.update(kw)
 
@@ -146,8 +146,7 @@ class BaseParameter:
 
         if not args:
             if self.required:
-                raise ValidationError(
-                    "'%s' needs to be specified" % (self.label))
+                raise ValidationError("'{}' needs to be specified".format(self.label))
             if self.multiple:
                 args = self.default
             else:
@@ -156,13 +155,13 @@ class BaseParameter:
         if self.regex:
             for arg in args:
                 if not self.regex.match(arg):
-                    raise ValidationError("%s:'%s' does not match pattern '%s'"
-                                          % (self.label, arg, self.regex.pattern))
+                    raise ValidationError("{}:'{}' does not match pattern '{}'".format(self.label,
+                            arg, self.regex.pattern))
         if self.maxsize is not None:
             for arg in args:
                 if len(arg) > self.maxsize:
-                    raise ValidationError("%s: is too large %d > %d"
-                                          % (self.label, len(arg), self.maxsize))
+                    raise ValidationError("{}: is too large {} > {}".format(self.label, len(arg),
+                                                                            self.maxsize))
 
         try:
             arg = self.parse_from_args(args)
@@ -173,8 +172,7 @@ class BaseParameter:
                 traceback.print_exc()
             raise e
         if arg is None:
-            raise ValidationError("need %s: no default provided by config"
-                                  % (self.fullName,))
+            raise ValidationError("need {}: no default provided by config".format(self.fullName))
         return arg
 
     def updateFromKwargs(self, properties, kwargs, collector, **unused):
@@ -269,8 +267,8 @@ class UserNameParameter(StringParameter):
         if self.need_email:
             res = VALID_EMAIL_ADDR.search(s)
             if res is None:
-                raise ValidationError("%s: please fill in email address in the "
-                                      "form 'User <email@email.com>'" % (self.name,))
+                raise ValidationError(("{}: please fill in email address in the "
+                                      "form 'User <email@email.com>'").format(self.name))
         return s
 
 
@@ -286,8 +284,8 @@ class ChoiceStringParameter(BaseParameter):
 
     def parse_from_arg(self, s):
         if self.strict and s not in self.choices:
-            raise ValidationError(
-                "'%s' does not belong to list of available choices '%s'" % (s, self.choices))
+            raise ValidationError("'{}' does not belong to list of available choices '{}'".format(s,
+                    self.choices))
         return s
 
     def getChoices(self, master, scheduler, buildername):
@@ -312,14 +310,14 @@ class InheritBuildParameter(ChoiceStringParameter):
         arg = kwargs.get(self.fullName, [""])[0]
         split_arg = arg.split(" ")[0].split("/")
         if len(split_arg) != 2:
-            raise ValidationError("bad build: %s" % (arg))
+            raise ValidationError("bad build: {}".format(arg))
         builder, num = split_arg
         builder_status = master.status.getBuilder(builder)
         if not builder_status:
-            raise ValidationError("unknown builder: %s in %s" % (builder, arg))
+            raise ValidationError("unknown builder: {} in {}".format(builder, arg))
         b = builder_status.getBuild(int(num))
         if not b:
-            raise ValidationError("unknown build: %d in %s" % (num, arg))
+            raise ValidationError("unknown build: {} in {}".format(num, arg))
         props = {self.name: (arg.split(" ")[0])}
         for name, value, source in b.getProperties().asList():
             if source == "Force Build Form":
@@ -498,8 +496,7 @@ class AnyPropertyParameter(NestedParameter):
 
         if not pname_validate.match(pname) \
                 or not pval_validate.match(pvalue):
-            raise ValidationError(
-                "bad property name='%s', value='%s'" % (pname, pvalue))
+            raise ValidationError("bad property name='{}', value='{}'".format(pname, pvalue))
         properties[pname] = pvalue
 
 
@@ -592,7 +589,8 @@ def oneCodebase(**kw):
 
 
 class PatchParameter(NestedParameter):
-    """A patch parameter contains pre-configure UI for all the needed components for a sourcestamp patch
+    """A patch parameter contains pre-configure UI for all the needed components for a
+       sourcestamp patch
     """
     columns = 1
 
@@ -679,26 +677,26 @@ class ForceScheduler(base.BaseScheduler):
                          name)
 
         if not self.checkIfListOfType(builderNames, (str,)):
-            config.error("ForceScheduler '%s': builderNames must be a list of strings: %r" %
-                         (name, builderNames))
+            config.error("ForceScheduler '{}': builderNames must be a list of strings: {}".format(
+                    name, repr(builderNames)))
 
         if self.checkIfType(reason, BaseParameter):
             self.reason = reason
         else:
-            config.error("ForceScheduler '%s': reason must be a StringParameter: %r" %
-                         (name, reason))
+            config.error("ForceScheduler '{}': reason must be a StringParameter: {}".format(
+                    name, repr(reason)))
 
         if properties is None:
             properties = []
         if not self.checkIfListOfType(properties, BaseParameter):
-            config.error("ForceScheduler '%s': properties must be a list of BaseParameters: %r" %
-                         (name, properties))
+            config.error(("ForceScheduler '{}': properties must be "
+                          "a list of BaseParameters: {}").format(name, repr(properties)))
 
         if self.checkIfType(username, BaseParameter):
             self.username = username
         else:
-            config.error("ForceScheduler '%s': username must be a StringParameter: %r" %
-                         (name, username))
+            config.error("ForceScheduler '{}': username must be a StringParameter: {}".format(name,
+                    repr(username)))
 
         self.forcedProperties = []
         self.label = name if label is None else label
@@ -707,22 +705,20 @@ class ForceScheduler(base.BaseScheduler):
         if codebases is None:
             codebases = [CodebaseParameter(codebase='')]
         elif not codebases:
-            config.error("ForceScheduler '%s': 'codebases' cannot be empty;"
-                         " use [CodebaseParameter(codebase='', hide=True)] if needed: %r " % (
-                             name, codebases))
+            config.error(("ForceScheduler '{}': 'codebases' cannot be empty;"
+                          " use [CodebaseParameter(codebase='', hide=True)] if needed: {} ").format(
+                                name, repr(codebases)))
         elif not isinstance(codebases, list):
-            config.error("ForceScheduler '%s': 'codebases' should be a list of strings or CodebaseParameter,"
-                         " not %s" % (
-                             name, type(codebases)))
+            config.error(("ForceScheduler '{}': 'codebases' should be a list of strings "
+                          "or CodebaseParameter, not {}").format(name, type(codebases)))
 
         codebase_dict = {}
         for codebase in codebases:
             if isinstance(codebase, str):
                 codebase = CodebaseParameter(codebase=codebase)
             elif not isinstance(codebase, CodebaseParameter):
-                config.error("ForceScheduler '%s': 'codebases' must be a list of strings"
-                             " or CodebaseParameter objects: %r" % (
-                                 name, codebases))
+                config.error(("ForceScheduler '{}': 'codebases' must be a list of strings "
+                              "or CodebaseParameter objects: {}").format(name, repr(codebases)))
 
             self.forcedProperties.append(codebase)
             codebase_dict[codebase.codebase] = dict(
