@@ -13,8 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
 
 import re
 import textwrap
@@ -30,7 +28,7 @@ from buildbot.steps.source.base import Source
 
 
 @implementer(IRenderable)
-class RepoDownloadsFromProperties(util.ComparableMixin, object):
+class RepoDownloadsFromProperties(util.ComparableMixin):
     parse_download_re = (re.compile(r"repo download ([^ ]+) ([0-9]+/[0-9]+)"),
                          re.compile(r"([^ ]+) ([0-9]+/[0-9]+)"),
                          re.compile(r"([^ ]+)/([0-9]+/[0-9]+)"),
@@ -52,8 +50,9 @@ class RepoDownloadsFromProperties(util.ComparableMixin, object):
     def parseDownloadProperty(self, s):
         """
          lets try to be nice in the format we want
-         can support several instances of "repo download proj number/patch" (direct copy paste from gerrit web site)
-         or several instances of "proj number/patch" (simpler version)
+         can support several instances of "repo download proj number/patch"
+         (direct copy paste from gerrit web site) or several instances of "proj number/patch"
+         (simpler version)
          This feature allows integrator to build with several pending interdependent changes.
          returns list of repo downloads sent to the worker
          """
@@ -63,14 +62,14 @@ class RepoDownloadsFromProperties(util.ComparableMixin, object):
         for cur_re in self.parse_download_re:
             res = cur_re.search(s)
             while res:
-                ret.append("%s %s" % (res.group(1), res.group(2)))
+                ret.append("{} {}".format(res.group(1), res.group(2)))
                 s = s[:res.start(0)] + s[res.end(0):]
                 res = cur_re.search(s)
         return ret
 
 
 @implementer(IRenderable)
-class RepoDownloadsFromChangeSource(util.ComparableMixin, object):
+class RepoDownloadsFromChangeSource(util.ComparableMixin):
     compare_attrs = ('codebase',)
 
     def __init__(self, codebase=None):
@@ -85,10 +84,9 @@ class RepoDownloadsFromChangeSource(util.ComparableMixin, object):
         for change in changes:
             if ("event.type" in change.properties and
                     change.properties["event.type"] == "patchset-created"):
-                downloads.append("%s %s/%s" % (change.properties["event.change.project"],
-                                               change.properties[
-                                                   "event.change.number"],
-                                               change.properties["event.patchSet.number"]))
+                downloads.append("{} {}/{}".format(change.properties["event.change.project"],
+                                                   change.properties["event.change.number"],
+                                                   change.properties["event.patchSet.number"]))
         return downloads
 
 
@@ -171,7 +169,7 @@ class Repo(Source):
         self.repoDownloads = repoDownloads
         self.depth = depth
         self.syncQuietly = syncQuietly
-        Source.__init__(self, **kwargs)
+        super().__init__(**kwargs)
 
         assert self.manifestURL is not None
 
@@ -219,18 +217,16 @@ class Repo(Source):
         # does not make sense to logEnviron for each command (just for first)
         self.logEnviron = False
         cmd.useLog(self.stdio_log, False)
-        self.stdio_log.addHeader(
-            "Starting command: %s\n" % (" ".join(command), ))
-        self.step_status.setText(["%s" % (" ".join(command[:2]))])
+        self.stdio_log.addHeader("Starting command: {}\n".format(" ".join(command)))
+        self.step_status.setText(["{}".format(" ".join(command[:2]))])
         d = self.runCommand(cmd)
 
         @d.addCallback
         def evaluateCommand(_):
             if abandonOnFailure and cmd.didFail():
-                self.descriptionDone = "repo failed at: %s" % (
-                    " ".join(command[:2]))
-                self.stdio_log.addStderr(
-                    "Source step failed while running command %s\n" % cmd)
+                self.descriptionDone = "repo failed at: {}".format(" ".join(command[:2]))
+                self.stdio_log.addStderr(("Source step failed while running command {}\n"
+                                          ).format(cmd))
                 raise buildstep.BuildStepFailed()
             return cmd.rc
         return d
@@ -252,8 +248,8 @@ class Repo(Source):
         self.filterManifestPatches()
 
         if self.repoDownloads:
-            self.stdio_log.addHeader(
-                "will download:\n" + "repo download " + "\nrepo download ".join(self.repoDownloads) + "\n")
+            self.stdio_log.addHeader("will download:\nrepo download {}\n".format(
+                    "\nrepo download ".join(self.repoDownloads)))
 
         self.willRetryInCaseOfFailure = True
 
@@ -297,10 +293,11 @@ class Repo(Source):
                              '--depth', str(self.depth)])
 
         if self.manifestOverrideUrl:
-            self.stdio_log.addHeader(
-                "overriding manifest with %s\n" % (self.manifestOverrideUrl))
-            local_file = yield self.pathExists(self.build.path_module.join(self.workdir,
-                                                                           self.manifestOverrideUrl))
+            self.stdio_log.addHeader(("overriding manifest with {}\n"
+                                      ).format(self.manifestOverrideUrl))
+
+            local_path = self.build.path_module.join(self.workdir, self.manifestOverrideUrl)
+            local_file = yield self.pathExists(local_path)
             if local_file:
                 yield self._Cmd(["cp", "-f", self.manifestOverrideUrl, "manifest_override.xml"])
             else:
@@ -309,7 +306,8 @@ class Repo(Source):
                             workdir=self.build.path_module.join(self.workdir, ".repo"))
 
         for command in self.manifestDownloads:
-            yield self._Cmd(command, workdir=self.build.path_module.join(self.workdir, ".repo", "manifests"))
+            yield self._Cmd(command, workdir=self.build.path_module.join(self.workdir, ".repo",
+                                                                         "manifests"))
 
         command = ['sync', '--force-sync']
         if self.jobs:
@@ -319,8 +317,8 @@ class Repo(Source):
         if self.syncQuietly:
             command.append('-q')
         self.step_status.setText(["repo sync"])
-        self.stdio_log.addHeader("synching manifest %s from branch %s from %s\n"
-                                 % (self.manifestFile, self.manifestBranch, self.manifestURL))
+        self.stdio_log.addHeader("synching manifest {} from branch {} from {}\n".format(
+                self.manifestFile, self.manifestBranch, self.manifestURL))
         yield self._repoCmd(command)
 
         command = ['manifest', '-r', '-o', 'manifest-original.xml']
@@ -347,8 +345,7 @@ class Repo(Source):
         self.repo_downloaded = ""
         for download in self.repoDownloads:
             command = ['download'] + download.split(' ')
-            self.stdio_log.addHeader("downloading changeset %s\n"
-                                     % (download))
+            self.stdio_log.addHeader("downloading changeset {}\n".format(download))
 
             retry = self.mirror_sync_retry + 1
             while retry > 0:
@@ -357,13 +354,12 @@ class Repo(Source):
                 if not self._findErrorMessages(self.ref_not_found_re):
                     break
                 retry -= 1
-                self.stdio_log.addStderr(
-                    "failed downloading changeset %s\n" % (download))
+                self.stdio_log.addStderr("failed downloading changeset {}\n".format(download))
                 self.stdio_log.addHeader("wait one minute for mirror sync\n")
                 yield self._sleep(self.mirror_sync_sleep)
 
             if retry == 0:
-                self.descriptionDone = "repo: change %s does not exist" % download
+                self.descriptionDone = "repo: change {} does not exist".format(download)
                 raise buildstep.BuildStepFailed()
 
             if self.lastCommand.didFail() or self._findErrorMessages(self.cherry_pick_error_re):
@@ -371,7 +367,7 @@ class Repo(Source):
                 # in stdout, which reveals the merge errors and exit
                 command = ['forall', '-c', 'git', 'diff', 'HEAD']
                 yield self._repoCmd(command, abandonOnFailure=False)
-                self.descriptionDone = "download failed: %s" % download
+                self.descriptionDone = "download failed: {}".format(download)
                 raise buildstep.BuildStepFailed()
 
             if hasattr(self.lastCommand, 'stderr'):
@@ -383,9 +379,8 @@ class Repo(Source):
                     if not match2:
                         match2 = self.re_head.match(line)
                 if match1 and match2:
-                    self.repo_downloaded += "%s/%s %s " % (match1.group(1),
-                                                           match1.group(2),
-                                                           match2.group(1))
+                    self.repo_downloaded += "{}/{} {} ".format(match1.group(1), match1.group(2),
+                                                               match2.group(1))
 
         self.setProperty("repo_downloaded", self.repo_downloaded, "Source")
 
@@ -421,7 +416,8 @@ class Repo(Source):
             return
         # tarball path is absolute, so we cannot use worker's stat command
         # stat -c%Y gives mtime in second since epoch
-        res = yield self._Cmd(["stat", "-c%Y", self.tarball], collectStdout=True, abandonOnFailure=False)
+        res = yield self._Cmd(["stat", "-c%Y", self.tarball], collectStdout=True,
+                              abandonOnFailure=False)
         if not res:
             tarball_mtime = int(self.lastCommand.stdout)
             yield self._Cmd(["stat", "-c%Y", "."], collectStdout=True)
