@@ -37,7 +37,7 @@ from buildbot.util.eventual import eventually
 def makeStatusRemoteCommand(step, remote_command, args):
     self = remotecommand.RemoteCommand(
         remote_command, args, decodeRC={None: SUCCESS, 0: SUCCESS})
-    self.useLogDelayed('stdio', lambda arg: step.step_status.addLog('stdio'), True)
+    self.useLog(step.stdio_log)
     return self
 
 
@@ -82,6 +82,7 @@ class _TransferBuildStep(BuildStep):
         if self.cmd:
             d = self.cmd.interrupt(reason)
             return d
+        return None
 
 
 class FileUpload(_TransferBuildStep):
@@ -125,6 +126,7 @@ class FileUpload(_TransferBuildStep):
 
     def start(self):
         self.checkWorkerHasCommand("uploadFile")
+        self.stdio_log = self.addLog("stdio")
 
         source = self.workersrc
         masterdest = self.masterdest
@@ -137,7 +139,7 @@ class FileUpload(_TransferBuildStep):
                 % (source, masterdest))
 
         if self.description is None:
-            self.description = ['uploading %s' % (os.path.basename(source))]
+            self.description = ['uploading {}'.format(os.path.basename(source))]
 
         if self.descriptionDone is None:
             self.descriptionDone = self.description
@@ -157,8 +159,8 @@ class FileUpload(_TransferBuildStep):
             masterdest, self.maxsize, self.mode)
 
         if self.keepstamp and self.workerVersionIsOlderThan("uploadFile", "2.13"):
-            m = ("This worker (%s) does not support preserving timestamps. "
-                 "Please upgrade the worker." % self.build.workername)
+            m = (("This worker ({}) does not support preserving timestamps. "
+                  "Please upgrade the worker.").format(self.build.workername))
             raise WorkerTooOldError(m)
 
         # default arguments
@@ -210,6 +212,7 @@ class DirectoryUpload(_TransferBuildStep):
 
     def start(self):
         self.checkWorkerHasCommand("uploadDirectory")
+        self.stdio_log = self.addLog("stdio")
 
         source = self.workersrc
         masterdest = self.masterdest
@@ -218,10 +221,10 @@ class DirectoryUpload(_TransferBuildStep):
         # properly. TODO: maybe pass the master's basedir all the way down
         # into the BuildStep so we can do this better.
         masterdest = os.path.expanduser(masterdest)
-        log.msg("DirectoryUpload started, from worker %r to master %r"
-                % (source, masterdest))
+        log.msg("DirectoryUpload started, from worker {} to master {}".format(repr(source),
+                                                                              repr(masterdest)))
 
-        self.descriptionDone = "uploading %s" % os.path.basename(source)
+        self.descriptionDone = "uploading {}".format(os.path.basename(source))
         if self.url is not None:
             urlText = self.urlText
 
@@ -327,6 +330,7 @@ class MultipleFileUpload(_TransferBuildStep, CompositeStepMixin):
         cmd = makeStatusRemoteCommand(self, 'uploadDirectory', args)
         return self.runTransferCommand(cmd, dirWriter)
 
+    @defer.inlineCallbacks
     def startUpload(self, source, destdir):
         masterdest = os.path.join(destdir, os.path.basename(source))
         args = {
@@ -335,25 +339,23 @@ class MultipleFileUpload(_TransferBuildStep, CompositeStepMixin):
         }
 
         cmd = makeStatusRemoteCommand(self, 'stat', args)
-        d = self.runCommand(cmd)
+        yield self.runCommand(cmd)
+        if cmd.rc != 0:
+            self.addCompleteLog('stderr',
+                                'File {} not available at worker'.format(args))
+            return FAILURE
+        s = cmd.updates['stat'][-1]
+        if stat.S_ISDIR(s[stat.ST_MODE]):
+            result = yield self.uploadDirectory(source, masterdest)
+        elif stat.S_ISREG(s[stat.ST_MODE]):
+            result = yield self.uploadFile(source, masterdest)
+        else:
+            self.addCompleteLog('stderr',
+                                '{} is neither a regular file, nor a directory'.format(source))
+            return FAILURE
 
-        @d.addCallback
-        def checkStat(_):
-            s = cmd.updates['stat'][-1]
-            if stat.S_ISDIR(s[stat.ST_MODE]):
-                return self.uploadDirectory(source, masterdest)
-            elif stat.S_ISREG(s[stat.ST_MODE]):
-                return self.uploadFile(source, masterdest)
-            return defer.fail('%r is neither a regular file, nor a directory' % source)
-
-        @d.addCallback
-        def uploadDone(result):
-            d = defer.maybeDeferred(
-                self.uploadDone, result, source, masterdest)
-            d.addCallback(lambda _: result)
-            return d
-
-        return d
+        yield self.uploadDone(result, source, masterdest)
+        return result
 
     def uploadDone(self, result, source, masterdest):
         pass
@@ -367,13 +369,14 @@ class MultipleFileUpload(_TransferBuildStep, CompositeStepMixin):
         self.checkWorkerHasCommand("uploadDirectory")
         self.checkWorkerHasCommand("uploadFile")
         self.checkWorkerHasCommand("stat")
+        self.stdio_log = self.addLog("stdio")
 
         masterdest = os.path.expanduser(self.masterdest)
         sources = self.workersrcs if isinstance(self.workersrcs, list) else [self.workersrcs]
 
         if self.keepstamp and self.workerVersionIsOlderThan("uploadFile", "2.13"):
-            m = ("This worker (%s) does not support preserving timestamps. "
-                 "Please upgrade the worker." % self.build.workername)
+            m = (("This worker ({}) does not support preserving timestamps. "
+                  "Please upgrade the worker.").format(self.build.workername))
             raise WorkerTooOldError(m)
 
         if not sources:
@@ -382,8 +385,8 @@ class MultipleFileUpload(_TransferBuildStep, CompositeStepMixin):
         @defer.inlineCallbacks
         def globSources(sources):
             results = yield defer.gatherResults([
-                self.runGlob(
-                    os.path.join(self.workdir, source), abandonOnFailure=False) for source in sources
+                self.runGlob(os.path.join(self.workdir, source), abandonOnFailure=False)
+                for source in sources
             ])
             results = [self.workerPathToMasterPath(p) for p in flatten(results)]
             return results
@@ -403,9 +406,8 @@ class MultipleFileUpload(_TransferBuildStep, CompositeStepMixin):
             log.msg("MultipleFileUpload started, from worker %r to master %r" %
                     (sources, masterdest))
             nsrcs = len(sources)
-            self.descriptionDone = 'uploading %d %s' % (nsrcs, 'file'
-                                                        if nsrcs == 1 else
-                                                        'files')
+            self.descriptionDone = 'uploading {} {}'.format(nsrcs,
+                                                            'file' if nsrcs == 1 else 'files')
             return sources
 
         if self.glob:
@@ -452,6 +454,7 @@ class FileDownload(_TransferBuildStep):
 
     def start(self):
         self.checkWorkerHasCommand("downloadFile")
+        self.stdio_log = self.addLog("stdio")
 
         # we are currently in the buildmaster's basedir, so any non-absolute
         # paths will be interpreted relative to that
@@ -460,8 +463,7 @@ class FileDownload(_TransferBuildStep):
         log.msg("FileDownload started, from master %r to worker %r" %
                 (source, workerdest))
 
-        self.descriptionDone = "downloading to %s" % os.path.basename(
-            workerdest)
+        self.descriptionDone = "downloading to {}".format(os.path.basename(workerdest))
 
         # setup structures for reading the file
         try:
@@ -515,14 +517,14 @@ class StringDownload(_TransferBuildStep):
         self.maxsize = maxsize
         self.blocksize = blocksize
         if not isinstance(mode, (int, type(None))):
-            config.error(
-                "StringDownload step's mode must be an integer or None,"
-                " got '%s'" % mode)
+            config.error("StringDownload step's mode must be an integer or None, got '{}'".format(
+                    mode))
         self.mode = mode
 
     def start(self):
         # we use 'downloadFile' remote command on the worker
         self.checkWorkerHasCommand("downloadFile")
+        self.stdio_log = self.addLog("stdio")
 
         # we are currently in the buildmaster's basedir, so any non-absolute
         # paths will be interpreted relative to that
@@ -530,8 +532,7 @@ class StringDownload(_TransferBuildStep):
         log.msg("StringDownload started, from master to worker %r" %
                 workerdest)
 
-        self.descriptionDone = "downloading to %s" % os.path.basename(
-            workerdest)
+        self.descriptionDone = "downloading to {}".format(os.path.basename(workerdest))
 
         # setup structures for reading the file
         fileReader = remotetransfer.StringFileReader(self.s)
