@@ -17,6 +17,7 @@ from twisted.internet import defer
 from twisted.python import log
 
 from buildbot import config
+from buildbot.interfaces import IRenderable
 from buildbot.interfaces import ITriggerableScheduler
 from buildbot.process.buildstep import CANCELLED
 from buildbot.process.buildstep import EXCEPTION
@@ -65,10 +66,18 @@ class Trigger(BuildStep):
             config.error(
                 "You can't specify both alwaysUseLatest and updateSourceStamp"
             )
-        if not set(schedulerNames).issuperset(set(unimportantSchedulerNames)):
-            config.error(
-                "unimportantSchedulerNames must be a subset of schedulerNames"
-            )
+
+        def hasRenderable(l):
+            for s in l:
+                if IRenderable.providedBy(s):
+                    return True
+            return False
+
+        if not hasRenderable(schedulerNames) and not hasRenderable(unimportantSchedulerNames):
+            if not set(schedulerNames).issuperset(set(unimportantSchedulerNames)):
+                config.error(
+                    "unimportantSchedulerNames must be a subset of schedulerNames"
+                )
 
         self.schedulerNames = schedulerNames
         self.unimportantSchedulerNames = unimportantSchedulerNames
@@ -222,8 +231,9 @@ class Trigger(BuildStep):
                             builderNames[builderid] = builderDict["name"]
                         num = build['number']
                         url = self.master.status.getURLForBuild(builderid, num)
-                        yield self.addURL("%s: %s #%d" % (statusToString(build["results"]),
-                                                          builderNames[builderid], num), url)
+                        yield self.addURL("{}: {} #{}".format(statusToString(build["results"]),
+                                                              builderNames[builderid], num),
+                                          url)
 
     @defer.inlineCallbacks
     def run(self):
@@ -286,7 +296,7 @@ class Trigger(BuildStep):
                 # put the url to the brids, so that we can have the status from
                 # the beginning
                 url = self.master.status.getURLForBuildrequest(brid)
-                yield self.addURL("%s #%d" % (sch.name, brid), url)
+                yield self.addURL("{} #{}".format(sch.name, brid), url)
             dl.append(resultsDeferred)
             triggeredNames.append(sch.name)
             if self.ended:
@@ -320,4 +330,4 @@ class Trigger(BuildStep):
     def getCurrentSummary(self):
         if not self.triggeredNames:
             return {'step': 'running'}
-        return {'step': 'triggered %s' % (', '.join(self.triggeredNames))}
+        return {'step': 'triggered {}'.format(', '.join(self.triggeredNames))}
