@@ -13,6 +13,8 @@
 #
 # Copyright Buildbot Team Members
 
+import traceback
+
 import mock
 
 from twisted.internet import defer
@@ -29,7 +31,7 @@ from buildbot.process import factory
 from buildbot.process import results
 from buildbot.process import workerforbuilder
 from buildbot.steps import shell
-from buildbot.test.fake import fakedb
+from buildbot.test import fakedb
 from buildbot.test.fake import fakemaster
 from buildbot.test.fake import fakeprotocol
 from buildbot.test.util.misc import TestReactorMixin
@@ -84,7 +86,6 @@ class OldStyleCustomBuildStep(buildstep.BuildStep):
             else:
                 self.finished(results.SUCCESS)
         except Exception:
-            import traceback
             traceback.print_exc()
             self.failed(failure.Failure())
 
@@ -193,9 +194,13 @@ class RunSteps(unittest.TestCase, TestReactorMixin):
         yield wfb.attached(self.worker, {})
 
         # add the buildset/request
-        self.bsid, brids = yield self.master.db.buildsets.addBuildset(
-            sourcestamps=[{}], reason='x', properties={},
-            builderids=[80], waited_for=False)
+        sourcestamps = [
+            {'repository': '', 'project': '', 'codebase': ''}
+        ]
+        self.bsid, brids = yield self.master.db.buildsets.addBuildset(sourcestamps=sourcestamps,
+                                                                      reason='x', properties={},
+                                                                      builderids=[80],
+                                                                      waited_for=False)
 
         self.brdict = \
             yield self.master.db.buildrequests.getBuildRequest(brids[80])
