@@ -14,9 +14,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-
 import os
 import xml.dom.minidom
 
@@ -27,6 +24,7 @@ from buildbot.changes import svnpoller
 from buildbot.process.properties import Interpolate
 from buildbot.test.util import changesource
 from buildbot.test.util import gpo
+from buildbot.test.util.misc import TestReactorMixin
 
 # this is the output of "svn info --xml
 # svn+ssh://svn.twistedmatrix.com/svn/Twisted/trunk"
@@ -60,7 +58,7 @@ prefix_output_2 = b"""\
 """
 
 # this is the svn info output for a local repository, svn info --xml
-# file:///home/warner/stuff/Projects/Buildbot/trees/svnpoller/_trial_temp/test_vc/repositories/SVN-Repository
+# file:///home/warner/stuff/Projects/Buildbot/trees/svnpoller/_trial_temp/test_vc/repositories/SVN-Repository  # noqa pylint: disable=line-too-long
 prefix_output_3 = b"""\
 <?xml version="1.0"?>
 <info>
@@ -82,7 +80,7 @@ prefix_output_3 = b"""\
 </info>
 """
 
-# % svn info --xml file:///home/warner/stuff/Projects/Buildbot/trees/svnpoller/_trial_temp/test_vc/repositories/SVN-Repository/sample/trunk
+# % svn info --xml file:///home/warner/stuff/Projects/Buildbot/trees/svnpoller/_trial_temp/test_vc/repositories/SVN-Repository/sample/trunk  # noqa pylint: disable=line-too-long
 
 prefix_output_4 = b"""\
 <?xml version="1.0"?>
@@ -103,7 +101,7 @@ prefix_output_4 = b"""\
 </commit>
 </entry>
 </info>
-"""
+"""  # noqa pylint: disable=line-too-long
 
 
 # output from svn log on .../SVN-Repository/sample
@@ -254,9 +252,11 @@ def split_file(path):
 
 class TestSVNPoller(gpo.GetProcessOutputMixin,
                     changesource.ChangeSourceMixin,
+                    TestReactorMixin,
                     unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         self.setUpGetProcessOutput()
         return self.setUpChangeSource()
 
@@ -379,7 +379,7 @@ class TestSVNPoller(gpo.GetProcessOutputMixin,
         self.assertEqual(changes[0]['project'], '')
         self.assertEqual(changes[0]['repository'], base)
         self.assertEqual(changes[1]['branch'], "branch")
-        self.assertEqual(changes[1]['files'], [u"çmain.c"])
+        self.assertEqual(changes[1]['files'], ["çmain.c"])
         self.assertEqual(changes[1]['revision'], '3')
         self.assertEqual(changes[1]['project'], '')
         self.assertEqual(changes[1]['repository'], base)
@@ -388,7 +388,7 @@ class TestSVNPoller(gpo.GetProcessOutputMixin,
         self.assertEqual(len(changes), 1)
         self.assertEqual(changes[0]['branch'], None)
         self.assertEqual(changes[0]['revision'], '4')
-        self.assertEqual(changes[0]['files'], [u"version.c"])
+        self.assertEqual(changes[0]['files'], ["version.c"])
 
         # r5 should *not* create a change as it's a branch deletion
         changes = s.create_changes([logentries[5]])
@@ -399,7 +399,7 @@ class TestSVNPoller(gpo.GetProcessOutputMixin,
         self.assertEqual(len(changes), 1)
         self.assertEqual(changes[0]['branch'], 'branch')
         self.assertEqual(changes[0]['revision'], '6')
-        self.assertEqual(changes[0]['files'], [u"version.c"])
+        self.assertEqual(changes[0]['files'], ["version.c"])
 
     def makeInfoExpect(self, password='bbrocks'):
         args = ['svn', 'info', '--xml', '--non-interactive', sample_base,
@@ -443,7 +443,7 @@ class TestSVNPoller(gpo.GetProcessOutputMixin,
         self.assertEqual(changes[0]['codebase'], "overridden-codebase")
 
         self.assertEqual(changes[1]['branch'], "branch")
-        self.assertEqual(changes[1]['files'], [u'çmain.c'])
+        self.assertEqual(changes[1]['files'], ['çmain.c'])
         self.assertEqual(changes[1]['revision'], '3')
         self.assertEqual(changes[1]['project'], "overridden-project")
         self.assertEqual(changes[1]['repository'], "overridden-repository")
@@ -478,16 +478,17 @@ class TestSVNPoller(gpo.GetProcessOutputMixin,
         yield s.poll()
 
         self.assertEqual(self.master.data.updates.changesAdded, [{
-            'author': u'warner',
+            'author': 'warner',
+            'committer': None,
             'branch': 'branch',
             'category': None,
             'codebase': None,
-            'comments': u'make_branch',
-            'files': [u''],
+            'comments': 'make_branch',
+            'files': [''],
             'project': '',
             'properties': {},
             'repository':
-                'file:///usr/home/warner/stuff/Projects/Buildbot/trees/misc/_trial_temp/test_vc/repositories/SVN-Repository/sample',
+                'file:///usr/home/warner/stuff/Projects/Buildbot/trees/misc/_trial_temp/test_vc/repositories/SVN-Repository/sample',  # noqa pylint: disable=line-too-long
             'revision': '2',
             'revlink': '',
             'src': 'svn',
@@ -500,31 +501,33 @@ class TestSVNPoller(gpo.GetProcessOutputMixin,
         yield s.poll()
 
         self.assertEqual(self.master.data.updates.changesAdded, [{
-            'author': u'warner',
+            'author': 'warner',
+            'committer': None,
             'branch': 'branch',
             'category': None,
             'codebase': None,
-            'comments': u'commit_on_branch',
-            'files': [u'çmain.c'],
+            'comments': 'commit_on_branch',
+            'files': ['çmain.c'],
             'project': '',
             'properties': {},
             'repository':
-                'file:///usr/home/warner/stuff/Projects/Buildbot/trees/misc/_trial_temp/test_vc/repositories/SVN-Repository/sample',
+                'file:///usr/home/warner/stuff/Projects/Buildbot/trees/misc/_trial_temp/test_vc/repositories/SVN-Repository/sample',  # noqa pylint: disable=line-too-long
             'revision': '3',
             'revlink': '',
             'src': 'svn',
             'when_timestamp': None,
         }, {
-            'author': u'warner',
+            'author': 'warner',
+            'committer': None,
             'branch': None,
             'category': None,
             'codebase': None,
-            'comments': u'revised_to_2',
-            'files': [u'version.c'],
+            'comments': 'revised_to_2',
+            'files': ['version.c'],
             'project': '',
             'properties': {},
             'repository':
-                'file:///usr/home/warner/stuff/Projects/Buildbot/trees/misc/_trial_temp/test_vc/repositories/SVN-Repository/sample',
+                'file:///usr/home/warner/stuff/Projects/Buildbot/trees/misc/_trial_temp/test_vc/repositories/SVN-Repository/sample',  # noqa pylint: disable=line-too-long
             'revision': '4',
             'revlink': '',
             'src': 'svn',
@@ -640,7 +643,8 @@ class TestSVNPoller(gpo.GetProcessOutputMixin,
 
     def test_use_svnurl(self):
         base = "svn+ssh://svn.twistedmatrix.com/svn/Twisted/trunk"
-        self.assertRaises(TypeError, self.attachSVNPoller, svnurl=base)
+        with self.assertRaises(TypeError):
+            self.attachSVNPoller(svnurl=base)
 
 
 class TestSplitFile(unittest.TestCase):
