@@ -21,10 +21,11 @@ from twisted.trial import unittest
 from buildbot.data import exceptions
 from buildbot.data import resultspec
 from buildbot.data import workers
-from buildbot.test.fake import fakedb
+from buildbot.test import fakedb
 from buildbot.test.fake import fakemaster
 from buildbot.test.util import endpoint
 from buildbot.test.util import interfaces
+from buildbot.test.util.misc import TestReactorMixin
 
 testData = [
     fakedb.Builder(id=40, name='b1'),
@@ -253,11 +254,12 @@ class WorkersEndpoint(endpoint.EndpointMixin, unittest.TestCase):
         self.assertEqual(worker['paused'], True)
 
 
-class Worker(interfaces.InterfaceTests, unittest.TestCase):
+class Worker(TestReactorMixin, interfaces.InterfaceTests, unittest.TestCase):
 
     def setUp(self):
-        self.master = fakemaster.make_master(testcase=self,
-                                             wantMq=True, wantDb=True, wantData=True)
+        self.setUpTestReactor()
+        self.master = fakemaster.make_master(self, wantMq=True, wantDb=True,
+                                             wantData=True)
         self.rtype = workers.Worker(self.master)
         return self.master.db.insertTestData([
             fakedb.Master(id=13),
