@@ -20,12 +20,10 @@ import json
 import mock
 
 from twisted.internet import defer
-from twisted.internet import task
 from twisted.trial import unittest
 
 from buildbot.db import buildsets
-from buildbot.test.fake import fakedb
-from buildbot.test.fake import fakemaster
+from buildbot.test import fakedb
 from buildbot.test.util import connector_component
 from buildbot.test.util import db
 from buildbot.test.util import interfaces
@@ -39,8 +37,7 @@ class Tests(interfaces.InterfaceTests):
 
     def setUpTests(self):
         self.now = 9272359
-        self.clock = task.Clock()
-        self.clock.advance(self.now)
+        self.reactor.advance(self.now)
 
         # set up a sourcestamp with id 234 for use below
         return self.insertTestData([
@@ -84,9 +81,10 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_addBuildset_getBuildset(self):
-        bsid, brids = yield self.db.buildsets.addBuildset(sourcestamps=[234],
-                                                          reason='because', properties={}, builderids=[1],
-                                                          external_idstring='extid', _reactor=self.clock, waited_for=False)
+        bsid, brids = yield self.db.buildsets.addBuildset(
+                sourcestamps=[234], reason='because', properties={},
+                builderids=[1], external_idstring='extid', waited_for=False)
+
         # TODO: verify buildrequests too
         bsdict = yield self.db.buildsets.getBuildset(bsid)
         validation.verifyDbDict(self, 'bsdict', bsdict)
@@ -103,7 +101,7 @@ class Tests(interfaces.InterfaceTests):
         bsid_brids = yield self.db.buildsets.addBuildset(
                 sourcestamps=[234], reason='because', properties={},
                 builderids=[1], external_idstring='extid',
-                submitted_at=epoch2datetime(8888888), _reactor=self.clock,
+                submitted_at=epoch2datetime(8888888),
                 waited_for=False)
         bsdict = yield self.db.buildsets.getBuildset(bsid_brids[0])
 
@@ -141,25 +139,6 @@ class Tests(interfaces.InterfaceTests):
         "returns an empty dict even if no such buildset exists"
         return self.do_test_getBuildsetProperties(91, [], dict())
 
-    @defer.inlineCallbacks
-    def test_getBuildset_incomplete_None(self):
-        yield self.insertTestData([
-            fakedb.Buildset(id=91, complete=0,
-                            complete_at=None, results=-1, submitted_at=266761875,
-                            external_idstring='extid', reason='rsn'),
-            fakedb.BuildsetSourceStamp(buildsetid=91, sourcestampid=234),
-        ])
-        bsdict = yield self.db.buildsets.getBuildset(91)
-
-        validation.verifyDbDict(self, 'bsdict', bsdict)
-        self.assertEqual(bsdict, dict(external_idstring='extid',
-                                      reason='rsn', sourcestamps=[234],
-                                      submitted_at=datetime.datetime(1978, 6, 15, 12, 31, 15,
-                                                                     tzinfo=UTC),
-                                      complete=False, complete_at=None, results=-1,
-                                      bsid=91,
-                                      parent_buildid=None, parent_relationship=None))
-
     @defer.inlineCallbacks
     def test_getBuildset_incomplete_zero(self):
         yield self.insertTestData([
@@ -175,7 +154,8 @@ class Tests(interfaces.InterfaceTests):
                                       reason='rsn', sourcestamps=[234],
                                       submitted_at=datetime.datetime(1978, 6, 15, 12, 31, 15,
                                                                      tzinfo=UTC),
-                                      complete=False, complete_at=None, results=-1,
+                                      complete=False,
+                                      complete_at=epoch2datetime(0), results=-1,
                                       bsid=91,
                                       parent_buildid=None, parent_relationship=None))
 
@@ -289,22 +269,19 @@ class Tests(interfaces.InterfaceTests):
     def test_completeBuildset_already_completed(self):
         d = self.insert_test_getBuildsets_data()
         d.addCallback(lambda _:
-                      self.db.buildsets.completeBuildset(bsid=92, results=6,
-                                                         _reactor=self.clock))
+                      self.db.buildsets.completeBuildset(bsid=92, results=6))
         return self.assertFailure(d, buildsets.AlreadyCompleteError)
 
     def test_completeBuildset_missing(self):
         d = self.insert_test_getBuildsets_data()
         d.addCallback(lambda _:
-                      self.db.buildsets.completeBuildset(bsid=93, results=6,
-                                                         _reactor=self.clock))
+                      self.db.buildsets.completeBuildset(bsid=93, results=6))
         return self.assertFailure(d, buildsets.AlreadyCompleteError)
 
     @defer.inlineCallbacks
     def test_completeBuildset(self):
         yield self.insert_test_getBuildsets_data()
-        yield self.db.buildsets.completeBuildset(bsid=91, results=6,
-                                                 _reactor=self.clock)
+        yield self.db.buildsets.completeBuildset(bsid=91, results=6)
         bsdicts = yield self.db.buildsets.getBuildsets()
 
         bsdicts = [(bsdict['bsid'], bsdict['complete'],
@@ -423,11 +400,8 @@ class RealTests(Tests):
     @defer.inlineCallbacks
     def test_addBuildset_simple(self):
         (bsid, brids) = yield self.db.buildsets.addBuildset(
-                                            sourcestamps=[234], reason='because',
-                                            properties={}, builderids=[2],
-                                            external_idstring='extid',
-                                            waited_for=True,
-                                            _reactor=self.clock)
+                sourcestamps=[234], reason='because', properties={},
+                builderids=[2], external_idstring='extid', waited_for=True)
 
         def thd(conn):
             # we should only have one brid
@@ -506,21 +480,20 @@ class RealTests(Tests):
         yield self.db.pool.do(thd)
 
 
-class TestFakeDB(unittest.TestCase, Tests):
+class TestFakeDB(unittest.TestCase, connector_component.FakeConnectorComponentMixin, Tests):
 
+    @defer.inlineCallbacks
     def setUp(self):
-        self.master = fakemaster.make_master(wantDb=True, testcase=self)
-        self.db = self.master.db
-        self.db.checkForeignKeys = True
-        self.insertTestData = self.db.insertTestData
-        return self.setUpTests()
+        yield self.setUpConnectorComponent()
+        yield self.setUpTests()
 
     @defer.inlineCallbacks
     def test_addBuildset_bad_waited_for(self):
         # only the fake db asserts on the type of waited_for
         d = self.db.buildsets.addBuildset(sourcestamps=[234], reason='because',
-                                          properties={}, builderids=[1], external_idstring='extid',
-                                          waited_for='wat', _reactor=self.clock)
+                                          properties={}, builderids=[1],
+                                          external_idstring='extid',
+                                          waited_for='wat')
         yield self.assertFailure(d, AssertionError)
 
 
