@@ -13,10 +13,11 @@
 #
 # Copyright Buildbot Team Members
 
+import random
+
 import mock
 
 from twisted.internet import defer
-from twisted.internet import reactor
 from twisted.python import failure
 from twisted.trial import unittest
 
@@ -24,7 +25,7 @@ from buildbot import config
 from buildbot.db import buildrequests
 from buildbot.process import buildrequestdistributor
 from buildbot.process import factory
-from buildbot.test.fake import fakedb
+from buildbot.test import fakedb
 from buildbot.test.fake import fakemaster
 from buildbot.test.util.misc import TestReactorMixin
 from buildbot.test.util.warnings import assertProducesWarning
@@ -73,6 +74,7 @@ class TestBRDBase(TestReactorMixin, unittest.TestCase):
     def tearDown(self):
         if self.brd.running:
             return self.brd.stopService()
+        return None
 
     def make_workers(self, worker_count):
         rows = self.base_rows[:]
@@ -109,7 +111,7 @@ class TestBRDBase(TestReactorMixin, unittest.TestCase):
         def maybeStartBuild(worker, builds):
             self.startedBuilds.append((worker.name, builds))
             d = defer.Deferred()
-            reactor.callLater(0, d.callback, True)
+            self.reactor.callLater(0, d.callback, True)
             return d
         bldr.maybeStartBuild = maybeStartBuild
         bldr.getCollapseRequestsFn = lambda: False
@@ -191,7 +193,7 @@ class Test(TestBRDBase):
         def slow_sorter(master, bldrs):
             bldrs.sort(key=lambda b1: b1.name)
             d = defer.Deferred()
-            reactor.callLater(0, d.callback, bldrs)
+            self.reactor.callLater(0, d.callback, bldrs)
 
             def done(_):
                 return _
@@ -215,8 +217,7 @@ class Test(TestBRDBase):
         def _maybeStartBuildsOnBuilder(n):
             # fail slowly, so that the activity loop doesn't exit too soon
             d = defer.Deferred()
-            reactor.callLater(0,
-                              d.errback, failure.Failure(RuntimeError("oh noes")))
+            self.reactor.callLater(0, d.errback, failure.Failure(RuntimeError("oh noes")))
             return d
         self.brd._maybeStartBuildsOnBuilder = _maybeStartBuildsOnBuilder
 
@@ -367,7 +368,7 @@ class TestMaybeStartBuilds(TestBRDBase):
 
     @defer.inlineCallbacks
     def setUp(self):
-        super().setUp()
+        yield super().setUp()
 
         self.startedBuilds = []
 
@@ -418,8 +419,8 @@ class TestMaybeStartBuilds(TestBRDBase):
             fakedb.BuildRequest(id=10, buildsetid=11, builderid=77,
                                 submitted_at=130000),
         ]
-        yield self.do_test_maybeStartBuildsOnBuilder(rows=rows,
-                                                     exp_claims=[10], exp_builds=[('test-worker1', [10])])
+        yield self.do_test_maybeStartBuildsOnBuilder(rows=rows, exp_claims=[10],
+                                                     exp_builds=[('test-worker1', [10])])
 
     @defer.inlineCallbacks
     def test_sorted_by_submit_time(self):
@@ -431,8 +432,8 @@ class TestMaybeStartBuilds(TestBRDBase):
             fakedb.BuildRequest(id=11, buildsetid=11, builderid=77,
                                 submitted_at=135000),
         ]
-        yield self.do_test_maybeStartBuildsOnBuilder(rows=rows,
-                                                     exp_claims=[10], exp_builds=[('test-worker1', [10])])
+        yield self.do_test_maybeStartBuildsOnBuilder(rows=rows, exp_claims=[10],
+                                                     exp_builds=[('test-worker1', [10])])
 
     @defer.inlineCallbacks
     def test_limited_by_available_workers(self):
@@ -443,8 +444,8 @@ class TestMaybeStartBuilds(TestBRDBase):
             fakedb.BuildRequest(id=11, buildsetid=11, builderid=77,
                                 submitted_at=135000),
         ]
-        yield self.do_test_maybeStartBuildsOnBuilder(rows=rows,
-                                                     exp_claims=[10], exp_builds=[('test-worker2', [10])])
+        yield self.do_test_maybeStartBuildsOnBuilder(rows=rows, exp_claims=[10],
+                                                     exp_builds=[('test-worker2', [10])])
 
     @defer.inlineCallbacks
     def test_slow_db(self):
@@ -458,7 +459,7 @@ class TestMaybeStartBuilds(TestBRDBase):
             res_d = old_getBuildRequests(*args, **kwargs)
             long_d = defer.Deferred()
             long_d.addCallback(lambda _: res_d)
-            reactor.callLater(0, long_d.callback, None)
+            self.reactor.callLater(0, long_d.callback, None)
             return long_d
         self.master.db.buildrequests.getBuildRequests = longGetBuildRequests
 
@@ -468,8 +469,8 @@ class TestMaybeStartBuilds(TestBRDBase):
             fakedb.BuildRequest(id=11, buildsetid=11, builderid=77,
                                 submitted_at=135000),
         ]
-        yield self.do_test_maybeStartBuildsOnBuilder(rows=rows,
-                                                     exp_claims=[10], exp_builds=[('test-worker1', [10])])
+        yield self.do_test_maybeStartBuildsOnBuilder(rows=rows, exp_claims=[10],
+                                                     exp_builds=[('test-worker1', [10])])
 
     @defer.inlineCallbacks
     def test_limited_by_canStartBuild(self):
@@ -500,9 +501,9 @@ class TestMaybeStartBuilds(TestBRDBase):
             fakedb.BuildRequest(id=12, buildsetid=11, builderid=77,
                                 submitted_at=140000),
         ]
-        yield self.do_test_maybeStartBuildsOnBuilder(rows=rows,
-                                                     exp_claims=[10, 11], exp_builds=[
-                                                         ('test-worker1', [10]), ('test-worker3', [11])])
+        yield self.do_test_maybeStartBuildsOnBuilder(rows=rows, exp_claims=[10, 11],
+                                                     exp_builds=[('test-worker1', [10]),
+                                                                 ('test-worker3', [11])])
 
         # we expect brids in order (10-11-12),
         # with each searched in reverse order of workers (3-2-1) available (due
@@ -567,10 +568,9 @@ class TestMaybeStartBuilds(TestBRDBase):
             fakedb.BuildRequest(id=11, buildsetid=11, builderid=77,
                                 submitted_at=135000),
         ]
-        yield self.do_test_maybeStartBuildsOnBuilder(rows=rows,
-                                                     exp_claims=[10, 11],
-                                                     exp_builds=[
-                                                         ('test-worker2', [10]), ('test-worker1', [11])])
+        yield self.do_test_maybeStartBuildsOnBuilder(rows=rows, exp_claims=[10, 11],
+                                                     exp_builds=[('test-worker2', [10]),
+                                                     ('test-worker1', [11])])
 
     @defer.inlineCallbacks
     def test_bldr_maybeStartBuild_fails_always(self):
@@ -593,8 +593,8 @@ class TestMaybeStartBuilds(TestBRDBase):
         yield self.do_test_maybeStartBuildsOnBuilder(rows=rows,
                                                      # claimed again so none taken!
                                                      exp_claims=[],
-                                                     exp_builds=[
-                                                         ('test-worker2', [10]), ('test-worker1', [11])])
+                                                     exp_builds=[('test-worker2', [10]),
+                                                                 ('test-worker1', [11])])
 
     @defer.inlineCallbacks
     def test_bldr_maybeStartBuild_fails_once(self):
@@ -638,8 +638,8 @@ class TestMaybeStartBuilds(TestBRDBase):
         rows = self.base_rows + [
             fakedb.BuildRequest(id=11, buildsetid=11, builderid=77),
         ]
-        yield self.do_test_maybeStartBuildsOnBuilder(rows=rows,
-                                                     exp_claims=[11], exp_builds=[('test-worker2', [11])])
+        yield self.do_test_maybeStartBuildsOnBuilder(rows=rows, exp_claims=[11],
+                                                     exp_builds=[('test-worker2', [11])])
 
     @defer.inlineCallbacks
     def test_nextWorker_None(self):
@@ -721,8 +721,8 @@ class TestMaybeStartBuilds(TestBRDBase):
             fakedb.BuildRequest(id=11, buildsetid=11, builderid=77,
                                 submitted_at=135000),
         ]
-        yield self.do_test_maybeStartBuildsOnBuilder(rows=rows,
-                                                     exp_claims=[11], exp_builds=[('test-worker1', [11])])
+        yield self.do_test_maybeStartBuildsOnBuilder(rows=rows, exp_claims=[11],
+                                                     exp_builds=[('test-worker1', [11])])
 
     # nextWorker
     @defer.inlineCallbacks
@@ -775,7 +775,6 @@ class TestMaybeStartBuilds(TestBRDBase):
         return self.do_test_nextWorker(nextWorker, exp_choice=0, exp_warning=True)
 
     def test_nextWorker_default(self):
-        import random
         self.patch(random, 'choice', nth_worker(2))
         return self.do_test_nextWorker(None, exp_choice=2)
 
@@ -823,8 +822,8 @@ class TestMaybeStartBuilds(TestBRDBase):
                 exp_builds.append(('test-worker%d' % worker, [choice]))
                 worker = worker - 1
 
-        yield self.do_test_maybeStartBuildsOnBuilder(rows=rows,
-                                                     exp_claims=sorted(exp_claims), exp_builds=exp_builds)
+        yield self.do_test_maybeStartBuildsOnBuilder(rows=rows, exp_claims=sorted(exp_claims),
+                                                     exp_builds=exp_builds)
 
     def test_nextBuild_default(self):
         "default chooses the first in the list, which should be the earliest"
