@@ -33,11 +33,16 @@ from buildbot.test.fake.remotecommand import ExpectRemoteRef
 from buildbot.test.fake.remotecommand import ExpectShell
 from buildbot.test.util import config as configmixin
 from buildbot.test.util import steps
+from buildbot.test.util.misc import TestReactorMixin
 
 
-class TestShellCommandExecution(steps.BuildStepMixin, unittest.TestCase, configmixin.ConfigErrorsMixin):
+class TestShellCommandExecution(steps.BuildStepMixin,
+                                configmixin.ConfigErrorsMixin,
+                                TestReactorMixin,
+                                unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         return self.setUpBuildStep()
 
     def tearDown(self):
@@ -319,9 +324,10 @@ class TestShellCommandExecution(steps.BuildStepMixin, unittest.TestCase, configm
             shell.ShellCommand()
 
 
-class TreeSize(steps.BuildStepMixin, unittest.TestCase):
+class TreeSize(steps.BuildStepMixin, TestReactorMixin, unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         return self.setUpBuildStep()
 
     def tearDown(self):
@@ -365,9 +371,11 @@ class TreeSize(steps.BuildStepMixin, unittest.TestCase):
         return self.runStep()
 
 
-class SetPropertyFromCommand(steps.BuildStepMixin, unittest.TestCase):
+class SetPropertyFromCommand(steps.BuildStepMixin, TestReactorMixin,
+                             unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         return self.setUpBuildStep()
 
     def tearDown(self):
@@ -394,7 +402,8 @@ class SetPropertyFromCommand(steps.BuildStepMixin, unittest.TestCase):
 
     def test_renderable_workdir(self):
         self.setupStep(
-            shell.SetPropertyFromCommand(property="res", command="cmd", workdir=properties.Interpolate('wkdir')))
+            shell.SetPropertyFromCommand(property="res", command="cmd",
+                                         workdir=properties.Interpolate('wkdir')))
         self.expectCommands(
             ExpectShell(workdir='wkdir',
                         command="cmd")
@@ -527,9 +536,10 @@ class SetPropertyFromCommand(steps.BuildStepMixin, unittest.TestCase):
             shell.SetPropertyFromCommand(command=["echo", "value"])
 
 
-class PerlModuleTest(steps.BuildStepMixin, unittest.TestCase):
+class PerlModuleTest(steps.BuildStepMixin, TestReactorMixin, unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         return self.setUpBuildStep()
 
     def tearDown(self):
@@ -592,7 +602,8 @@ class PerlModuleTest(steps.BuildStepMixin, unittest.TestCase):
                     -------------------
                     foo.pl (Wstat: 0 Tests: 4 Failed: 1)
                       Failed test:  0
-                    Files=1, Tests=4,  0 wallclock secs ( 0.06 usr  0.01 sys +  0.03 cusr  0.01 csys =  0.11 CPU)
+                    Files=1, Tests=4,  0 wallclock secs ( 0.06 usr  0.01 sys +  0.03 cusr
+                    0.01 csys =  0.11 CPU)
                     Result: FAIL"""))
             + ExpectShell.log('stdio', stderr=textwrap.dedent("""\
                     Failed 1/1 test programs. 1/4 subtests failed."""))
@@ -661,10 +672,13 @@ class Configure(unittest.TestCase):
         self.assertEqual(step.command, ['./configure'])
 
 
-class WarningCountingShellCommand(steps.BuildStepMixin, unittest.TestCase,
-                                  configmixin.ConfigErrorsMixin):
+class WarningCountingShellCommand(steps.BuildStepMixin,
+                                  configmixin.ConfigErrorsMixin,
+                                  TestReactorMixin,
+                                  unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         return self.setUpBuildStep()
 
     def tearDown(self):
@@ -975,9 +989,10 @@ class WarningCountingShellCommand(steps.BuildStepMixin, unittest.TestCase,
                    ("def.c", ".*", 22, 22),
         )
 
-        step = shell.WarningCountingShellCommand(command=['make'],
-                                                 suppressionList=properties.Property("suppressionsList"),
-                                                 warningExtractor=warningExtractor)
+        step = shell.WarningCountingShellCommand(
+            command=['make'],
+            suppressionList=properties.Property("suppressionsList"),
+            warningExtractor=warningExtractor)
 
         stdout = textwrap.dedent("""\
             abc.c:99: warning: seen 1
@@ -1008,9 +1023,10 @@ class WarningCountingShellCommand(steps.BuildStepMixin, unittest.TestCase,
             shell.WarningCountingShellCommand()
 
 
-class Compile(steps.BuildStepMixin, unittest.TestCase):
+class Compile(steps.BuildStepMixin, TestReactorMixin, unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         return self.setUpBuildStep()
 
     def tearDown(self):
@@ -1028,9 +1044,12 @@ class Compile(steps.BuildStepMixin, unittest.TestCase):
         self.assertEqual(step.command, ["make", "all"])
 
 
-class Test(steps.BuildStepMixin, unittest.TestCase):
+class Test(steps.BuildStepMixin, configmixin.ConfigErrorsMixin,
+           TestReactorMixin,
+           unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         self.setUpBuildStep()
 
     def tearDown(self):
