@@ -27,6 +27,7 @@ from buildbot.test.fake.remotecommand import Expect
 from buildbot.test.fake.remotecommand import ExpectRemoteRef
 from buildbot.test.fake.remotecommand import ExpectShell
 from buildbot.test.util import sourcesteps
+from buildbot.test.util.misc import TestReactorMixin
 
 
 def uploadString(cvsroot):
@@ -37,9 +38,11 @@ def uploadString(cvsroot):
     return behavior
 
 
-class TestCVS(sourcesteps.SourceStepMixin, unittest.TestCase):
+class TestCVS(sourcesteps.SourceStepMixin, TestReactorMixin,
+              unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         return self.setUpSourceStep()
 
     def tearDown(self):
@@ -80,7 +83,8 @@ class TestCVS(sourcesteps.SourceStepMixin, unittest.TestCase):
         self.assertEqual(step._cvsEntriesContainStickyDates(
             '/file/1.1/Fri May 17 23:20:00//D2013.10.08.11.20.33\nD'), True)
         self.assertEqual(step._cvsEntriesContainStickyDates(
-            '/file1/1.1/Fri May 17 23:20:00//\n/file2/1.1.2.3/Fri May 17 23:20:00//D2013.10.08.11.20.33\nD'), True)
+            '/file1/1.1/Fri May 17 23:20:00//\n'
+            '/file2/1.1.2.3/Fri May 17 23:20:00//D2013.10.08.11.20.33\nD'), True)
 
     def test_mode_full_clean_and_login(self):
         self.setupStep(
