@@ -28,7 +28,6 @@ from twisted.trial import unittest
 
 from buildbot import config
 from buildbot.process import remotetransfer
-from buildbot.process.properties import Properties
 from buildbot.process.results import EXCEPTION
 from buildbot.process.results import FAILURE
 from buildbot.process.results import SKIPPED
@@ -37,7 +36,7 @@ from buildbot.steps import transfer
 from buildbot.test.fake.remotecommand import Expect
 from buildbot.test.fake.remotecommand import ExpectRemoteRef
 from buildbot.test.util import steps
-from buildbot.util import bytes2unicode
+from buildbot.test.util.misc import TestReactorMixin
 from buildbot.util import unicode2bytes
 
 
@@ -90,9 +89,10 @@ class UploadError:
         raise RuntimeError('uh oh')
 
 
-class TestFileUpload(steps.BuildStepMixin, unittest.TestCase):
+class TestFileUpload(steps.BuildStepMixin, TestReactorMixin, unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         fd, self.destfile = tempfile.mkstemp()
         os.close(fd)
         os.unlink(self.destfile)
@@ -105,7 +105,8 @@ class TestFileUpload(steps.BuildStepMixin, unittest.TestCase):
 
     def testConstructorModeType(self):
         with self.assertRaises(config.ConfigErrors):
-            transfer.FileUpload(workersrc=__file__, masterdest='xyz', mode='g+rwx')
+            transfer.FileUpload(workersrc=__file__,
+                                masterdest='xyz', mode='g+rwx')
 
     def testBasic(self):
         self.setupStep(
@@ -160,7 +161,8 @@ class TestFileUpload(steps.BuildStepMixin, unittest.TestCase):
 
         self.expectOutcome(
             result=SUCCESS,
-            state_string="uploading %s" % os.path.basename(__file__))
+            state_string="uploading {}".format(os.path.basename(__file__))
+            )
 
         yield self.runStep()
 
@@ -175,8 +177,8 @@ class TestFileUpload(steps.BuildStepMixin, unittest.TestCase):
 
     def testDescriptionDone(self):
         self.setupStep(
-            transfer.FileUpload(workersrc=__file__, masterdest=self.destfile, url="http://server/file",
-                descriptionDone="Test File Uploaded"))
+            transfer.FileUpload(workersrc=__file__, masterdest=self.destfile,
+                                url="http://server/file", descriptionDone="Test File Uploaded"))
 
         self.step.addURL = Mock()
 
@@ -197,8 +199,8 @@ class TestFileUpload(steps.BuildStepMixin, unittest.TestCase):
 
     @defer.inlineCallbacks
     def testURL(self):
-        self.setupStep(
-            transfer.FileUpload(workersrc=__file__, masterdest=self.destfile, url="http://server/file"))
+        self.setupStep(transfer.FileUpload(workersrc=__file__, masterdest=self.destfile,
+                                           url="http://server/file"))
 
         self.step.addURL = Mock()
 
@@ -212,7 +214,8 @@ class TestFileUpload(steps.BuildStepMixin, unittest.TestCase):
 
         self.expectOutcome(
             result=SUCCESS,
-            state_string="uploading %s" % os.path.basename(__file__))
+            state_string="uploading {}".format(os.path.basename(__file__))
+            )
 
         yield self.runStep()
 
@@ -221,8 +224,9 @@ class TestFileUpload(steps.BuildStepMixin, unittest.TestCase):
 
     @defer.inlineCallbacks
     def testURLText(self):
-        self.setupStep(
-            transfer.FileUpload(workersrc=__file__, masterdest=self.destfile, url="http://server/file", urlText="testfile"))
+        self.setupStep(transfer.FileUpload(workersrc=__file__,
+                                           masterdest=self.destfile, url="http://server/file",
+                                           urlText="testfile"))
 
         self.step.addURL = Mock()
 
@@ -236,7 +240,8 @@ class TestFileUpload(steps.BuildStepMixin, unittest.TestCase):
 
         self.expectOutcome(
             result=SUCCESS,
-            state_string="uploading %s" % os.path.basename(__file__))
+            state_string="uploading {}".format(os.path.basename(__file__))
+            )
 
         yield self.runStep()
 
@@ -300,9 +305,11 @@ class TestFileUpload(steps.BuildStepMixin, unittest.TestCase):
             transfer.FileUpload('src')
 
 
-class TestDirectoryUpload(steps.BuildStepMixin, unittest.TestCase):
+class TestDirectoryUpload(steps.BuildStepMixin, TestReactorMixin,
+                          unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         self.destdir = os.path.abspath('destdir')
         if os.path.exists(self.destdir):
             shutil.rmtree(self.destdir)
@@ -388,7 +395,7 @@ class TestDirectoryUpload(steps.BuildStepMixin, unittest.TestCase):
 
         self.assertEqual(behavior.writer.cancel.called, True)
         self.assertEqual(
-                len(self.flushLoggedErrors(RuntimeError)), 1)
+            len(self.flushLoggedErrors(RuntimeError)), 1)
 
     def test_init_workersrc_keyword(self):
         step = transfer.DirectoryUpload(
@@ -408,9 +415,11 @@ class TestDirectoryUpload(steps.BuildStepMixin, unittest.TestCase):
             transfer.DirectoryUpload('src')
 
 
-class TestMultipleFileUpload(steps.BuildStepMixin, unittest.TestCase):
+class TestMultipleFileUpload(steps.BuildStepMixin, TestReactorMixin,
+                             unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         self.destdir = os.path.abspath('destdir')
         if os.path.exists(self.destdir):
             shutil.rmtree(self.destdir)
@@ -528,7 +537,8 @@ class TestMultipleFileUpload(steps.BuildStepMixin, unittest.TestCase):
             transfer.MultipleFileUpload(
                 workersrcs=["src*"], masterdest=self.destdir, glob=True))
         self.expectCommands(
-            Expect('glob', dict(path=os.path.join('wkdir', 'src*'), logEnviron=False))
+            Expect('glob', dict(path=os.path.join(
+                'wkdir', 'src*'), logEnviron=False))
             + Expect.update('files', ["srcfile"])
             + 0,
             Expect('stat', dict(file="srcfile",
@@ -552,11 +562,13 @@ class TestMultipleFileUpload(steps.BuildStepMixin, unittest.TestCase):
             transfer.MultipleFileUpload(
                 workersrcs=["src*"], masterdest=self.destdir, glob=True))
         self.expectCommands(
-            Expect('glob', {'path': os.path.join('wkdir', 'src*'), 'logEnviron': False})
+            Expect('glob', {'path': os.path.join(
+                'wkdir', 'src*'), 'logEnviron': False})
             + Expect.update('files', [])
             + 1,
         )
-        self.expectOutcome(result=SKIPPED, state_string="uploading 0 files (skipped)")
+        self.expectOutcome(
+            result=SKIPPED, state_string="uploading 0 files (skipped)")
         d = self.runStep()
         return d
 
@@ -681,7 +693,7 @@ class TestMultipleFileUpload(steps.BuildStepMixin, unittest.TestCase):
 
         self.assertEqual(behavior.writer.cancel.called, True)
         self.assertEqual(
-                len(self.flushLoggedErrors(RuntimeError)), 1)
+            len(self.flushLoggedErrors(RuntimeError)), 1)
 
     @defer.inlineCallbacks
     def testSubclass(self):
@@ -748,9 +760,11 @@ class TestMultipleFileUpload(steps.BuildStepMixin, unittest.TestCase):
             transfer.MultipleFileUpload(['srcfile'])
 
 
-class TestFileDownload(steps.BuildStepMixin, unittest.TestCase):
+class TestFileDownload(steps.BuildStepMixin, TestReactorMixin,
+                       unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         fd, self.destfile = tempfile.mkstemp()
         os.close(fd)
         os.unlink(self.destfile)
@@ -841,9 +855,11 @@ class TestFileDownload(steps.BuildStepMixin, unittest.TestCase):
             self.assertEqual(b''.join(read), contents)
 
 
-class TestStringDownload(steps.BuildStepMixin, unittest.TestCase):
+class TestStringDownload(steps.BuildStepMixin, TestReactorMixin,
+                         unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         return self.setUpBuildStep()
 
     def tearDown(self):
@@ -853,8 +869,8 @@ class TestStringDownload(steps.BuildStepMixin, unittest.TestCase):
 
     def testModeConfError(self):
         with self.assertRaisesRegex(config.ConfigErrors,
-                "StringDownload step's mode must be an integer or None,"
-                " got 'not-a-number'"):
+                                    "StringDownload step's mode must be an integer or None,"
+                                    " got 'not-a-number'"):
             transfer.StringDownload("string", "file", mode="not-a-number")
 
     @defer.inlineCallbacks
@@ -939,9 +955,11 @@ class TestStringDownload(steps.BuildStepMixin, unittest.TestCase):
             transfer.StringDownload('srcfile')
 
 
-class TestJSONStringDownload(steps.BuildStepMixin, unittest.TestCase):
+class TestJSONStringDownload(steps.BuildStepMixin, TestReactorMixin,
+                             unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         return self.setUpBuildStep()
 
     def tearDown(self):
@@ -1005,71 +1023,35 @@ class TestJSONStringDownload(steps.BuildStepMixin, unittest.TestCase):
             transfer.JSONStringDownload('srcfile')
 
 
-class TestJSONPropertiesDownload(unittest.TestCase):
+class TestJSONPropertiesDownload(steps.BuildStepMixin, TestReactorMixin, unittest.TestCase):
 
+    def setUp(self):
+        self.setUpTestReactor()
+        return self.setUpBuildStep()
+
+    def tearDown(self):
+        return self.tearDownBuildStep()
+
+    @defer.inlineCallbacks
     def testBasic(self):
-        s = transfer.JSONPropertiesDownload("props.json")
-        s.build = Mock()
-        props = Properties()
-        props.setProperty('key1', 'value1', 'test')
-        s.build.getProperties.return_value = props
-        s.build.getWorkerCommandVersion.return_value = '3.0'
-        ss = Mock()
-        ss.asDict.return_value = dict(revision="12345")
-        s.build.getAllSourceStamps.return_value = [ss]
+        self.setupStep(transfer.JSONPropertiesDownload("props.json"))
+        self.step.build.setProperty('key1', 'value1', 'test')
+        read = []
+        self.expectCommands(
+            Expect('downloadFile', dict(
+                workerdest="props.json", workdir='wkdir',
+                blocksize=16384, maxsize=None, mode=None,
+                reader=ExpectRemoteRef(remotetransfer.StringFileReader))
+            )
+            + Expect.behavior(downloadString(read.append))
+            + 0)
 
-        s.worker = Mock()
-        s.remote = Mock()
-
-        s.start()
-
-        for c in s.remote.method_calls:
-            name, command, args = c
-            commandName = command[3]
-            kwargs = command[-1]
-            if commandName == 'downloadFile':
-                self.assertEqual(kwargs['workerdest'], 'props.json')
-                reader = kwargs['reader']
-                data = reader.remote_read(100)
-                data = bytes2unicode(data)
-                actualJson = json.loads(data)
-                expectedJson = dict(sourcestamps=[ss.asDict()], properties={'key1': 'value1'})
-                self.assertEqual(actualJson, expectedJson)
-                break
-        else:
-            raise ValueError("No downloadFile command found")
-
-    def testBasicWorker2_16(self):
-        s = transfer.JSONPropertiesDownload("props.json")
-        s.build = Mock()
-        props = Properties()
-        props.setProperty('key1', 'value1', 'test')
-        s.build.getProperties.return_value = props
-        s.build.getWorkerCommandVersion.return_value = '2.16'
-        ss = Mock()
-        ss.asDict.return_value = dict(revision="12345")
-        s.build.getAllSourceStamps.return_value = [ss]
-
-        s.worker = Mock()
-        s.remote = Mock()
-
-        s.start()
-
-        for c in s.remote.method_calls:
-            name, command, args = c
-            commandName = command[3]
-            kwargs = command[-1]
-            if commandName == 'downloadFile':
-                self.assertEqual(kwargs['slavedest'], 'props.json')
-                reader = kwargs['reader']
-                data = reader.remote_read(100)
-                data = bytes2unicode(data)
-                actualJson = json.loads(data)
-                expectedJson = dict(sourcestamps=[ss.asDict()], properties={'key1': 'value1'})
-                self.assertEqual(actualJson, expectedJson)
-                break
-        else:
-            raise ValueError("No downloadFile command found")
+        self.expectOutcome(
+            result=SUCCESS, state_string="downloading to props.json")
+        yield self.runStep()
+        # we decode as key order is dependent of python version
+        self.assertEqual(json.loads((b''.join(read)).decode()), {
+                         "properties": {"key1": "value1"}, "sourcestamps": []})
 
     def test_init_workerdest_keyword(self):
         step = transfer.JSONPropertiesDownload(workerdest='dstfile')
