@@ -25,6 +25,7 @@ from buildbot.process.results import WARNINGS
 from buildbot.steps import vstudio
 from buildbot.test.fake.remotecommand import ExpectShell
 from buildbot.test.util import steps
+from buildbot.test.util.misc import TestReactorMixin
 
 real_log = r"""
 1>------ Build started: Project: lib1, Configuration: debug Win32 ------
@@ -45,7 +46,7 @@ real_log = r"""
 2>Build log was saved at "file://c:\another\similar\path\to\debug\BuildLog.htm"
 2>product - 1 error(s), 0 warning(s)
 ========== Build: 1 succeeded, 1 failed, 6 up-to-date, 0 skipped ==========
-"""
+"""  # noqa pylint: disable=line-too-long
 
 
 class TestAddEnvPath(unittest.TestCase):
@@ -172,16 +173,16 @@ class MSLogLineObserver(unittest.TestCase):
             ('o',
              '2>------ Build started: Project: product, Configuration: debug Win32 ------'),
             ('e',
-             '2>LINK : fatal error LNK1168: cannot open ../../debug/directory/dllname.dll for writing')
+             '2>LINK : fatal error LNK1168: cannot open ../../debug/directory/dllname.dll for writing')  # noqa pylint: disable=line-too-long
         ]
         warnings = [
             '1>------ Build started: Project: lib1, Configuration: debug Win32 ------',
-            "1>c:\\absolute\\path\\to\\systemlog.cpp(7) : warning C4100: 'op' : unreferenced formal parameter",
-            "1>c:\\absolute\\path\\to\\systemlog.cpp(12) : warning C4100: 'statusword' : unreferenced formal parameter",
-            "1>c:\\absolute\\path\\to\\systemlog.cpp(12) : warning C4100: 'op' : unreferenced formal parameter",
-            "1>c:\\absolute\\path\\to\\systemlog.cpp(17) : warning C4100: 'retryCounter' : unreferenced formal parameter",
-            "1>c:\\absolute\\path\\to\\systemlog.cpp(17) : warning C4100: 'op' : unreferenced formal parameter",
-            "1>c:\\absolute\\path\\to\\systemlog.cpp(22) : warning C4100: 'op' : unreferenced formal parameter",
+            "1>c:\\absolute\\path\\to\\systemlog.cpp(7) : warning C4100: 'op' : unreferenced formal parameter",  # noqa pylint: disable=line-too-long
+            "1>c:\\absolute\\path\\to\\systemlog.cpp(12) : warning C4100: 'statusword' : unreferenced formal parameter",  # noqa pylint: disable=line-too-long
+            "1>c:\\absolute\\path\\to\\systemlog.cpp(12) : warning C4100: 'op' : unreferenced formal parameter",  # noqa pylint: disable=line-too-long
+            "1>c:\\absolute\\path\\to\\systemlog.cpp(17) : warning C4100: 'retryCounter' : unreferenced formal parameter",  # noqa pylint: disable=line-too-long
+            "1>c:\\absolute\\path\\to\\systemlog.cpp(17) : warning C4100: 'op' : unreferenced formal parameter",  # noqa pylint: disable=line-too-long
+            "1>c:\\absolute\\path\\to\\systemlog.cpp(22) : warning C4100: 'op' : unreferenced formal parameter",  # noqa pylint: disable=line-too-long
             '2>------ Build started: Project: product, Configuration: debug Win32 ------',
         ]
         self.assertResult(nbFiles=1, nbErrors=1, nbProjects=2, nbWarnings=6,
@@ -197,13 +198,14 @@ class VCx(vstudio.VisualStudio):
         return super().start()
 
 
-class VisualStudio(steps.BuildStepMixin, unittest.TestCase):
+class VisualStudio(steps.BuildStepMixin, TestReactorMixin, unittest.TestCase):
 
     """
     Test L{VisualStudio} with a simple subclass, L{VCx}.
     """
 
     def setUp(self):
+        self.setUpTestReactor()
         return self.setUpBuildStep()
 
     def tearDown(self):
@@ -334,9 +336,10 @@ class VisualStudio(steps.BuildStepMixin, unittest.TestCase):
                 ['aa', 'bb', 'cc'])
 
 
-class TestVC6(steps.BuildStepMixin, unittest.TestCase):
+class TestVC6(steps.BuildStepMixin, TestReactorMixin, unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         return self.setUpBuildStep()
 
     def tearDown(self):
@@ -359,11 +362,11 @@ class TestVC6(steps.BuildStepMixin, unittest.TestCase):
             installdir + r'\Common\TOOLS;',
         ]
         if p:
-            path.insert(0, '%s;' % p)
+            path.insert(0, '{};'.format(p))
         if i:
-            include.insert(0, '%s;' % i)
+            include.insert(0, '{};'.format(i))
         if LIB:
-            lib.insert(0, '%s;' % LIB)
+            lib.insert(0, '{};'.format(LIB))
         return dict(
             INCLUDE=''.join(include),
             LIB=''.join(lib),
@@ -434,9 +437,10 @@ class TestVC6(steps.BuildStepMixin, unittest.TestCase):
         return self.runStep()
 
 
-class TestVC7(steps.BuildStepMixin, unittest.TestCase):
+class TestVC7(steps.BuildStepMixin, TestReactorMixin, unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         return self.setUpBuildStep()
 
     def tearDown(self):
@@ -462,11 +466,11 @@ class TestVC7(steps.BuildStepMixin, unittest.TestCase):
             installdir + r'\Common7\Tools\bin;',
         ]
         if p:
-            path.insert(0, '%s;' % p)
+            path.insert(0, '{};'.format(p))
         if i:
-            include.insert(0, '%s;' % i)
+            include.insert(0, '{};'.format(i))
         if LIB:
-            lib.insert(0, '%s;' % LIB)
+            lib.insert(0, '{};'.format(LIB))
         return dict(
             INCLUDE=''.join(include),
             LIB=''.join(lib),
@@ -564,11 +568,11 @@ class VC8ExpectedEnvMixin:
             path.insert(1, installdir + r'\VC\BIN\x86_amd64;')
             lib = [lb[:-1] + r'\amd64;' for lb in lib]
         if LIB:
-            lib.insert(0, '%s;' % LIB)
+            lib.insert(0, '{};'.format(LIB))
         if p:
-            path.insert(0, '%s;' % p)
+            path.insert(0, '{};'.format(p))
         if i:
-            include.insert(0, '%s;' % i)
+            include.insert(0, '{};'.format(i))
         return dict(
             INCLUDE=''.join(include),
             LIB=''.join(lib),
@@ -576,9 +580,11 @@ class VC8ExpectedEnvMixin:
         )
 
 
-class TestVC8(VC8ExpectedEnvMixin, steps.BuildStepMixin, unittest.TestCase):
+class TestVC8(VC8ExpectedEnvMixin, steps.BuildStepMixin, TestReactorMixin,
+              unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         return self.setUpBuildStep()
 
     def tearDown(self):
@@ -651,9 +657,11 @@ class TestVC8(VC8ExpectedEnvMixin, steps.BuildStepMixin, unittest.TestCase):
 
 
 class TestVCExpress9(VC8ExpectedEnvMixin, steps.BuildStepMixin,
+                     TestReactorMixin,
                      unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         return self.setUpBuildStep()
 
     def tearDown(self):
@@ -708,9 +716,11 @@ class TestVCExpress9(VC8ExpectedEnvMixin, steps.BuildStepMixin,
         return self.runStep()
 
 
-class TestVC9(VC8ExpectedEnvMixin, steps.BuildStepMixin, unittest.TestCase):
+class TestVC9(VC8ExpectedEnvMixin, steps.BuildStepMixin, TestReactorMixin,
+              unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         return self.setUpBuildStep()
 
     def tearDown(self):
@@ -732,9 +742,11 @@ class TestVC9(VC8ExpectedEnvMixin, steps.BuildStepMixin, unittest.TestCase):
         return self.runStep()
 
 
-class TestVC10(VC8ExpectedEnvMixin, steps.BuildStepMixin, unittest.TestCase):
+class TestVC10(VC8ExpectedEnvMixin, steps.BuildStepMixin, TestReactorMixin,
+               unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         return self.setUpBuildStep()
 
     def tearDown(self):
@@ -756,9 +768,11 @@ class TestVC10(VC8ExpectedEnvMixin, steps.BuildStepMixin, unittest.TestCase):
         return self.runStep()
 
 
-class TestVC11(VC8ExpectedEnvMixin, steps.BuildStepMixin, unittest.TestCase):
+class TestVC11(VC8ExpectedEnvMixin, steps.BuildStepMixin, TestReactorMixin,
+               unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         return self.setUpBuildStep()
 
     def tearDown(self):
@@ -780,9 +794,10 @@ class TestVC11(VC8ExpectedEnvMixin, steps.BuildStepMixin, unittest.TestCase):
         return self.runStep()
 
 
-class TestMsBuild(steps.BuildStepMixin, unittest.TestCase):
+class TestMsBuild(steps.BuildStepMixin, TestReactorMixin, unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         return self.setUpBuildStep()
 
     def tearDown(self):
@@ -794,7 +809,7 @@ class TestMsBuild(steps.BuildStepMixin, unittest.TestCase):
 
         self.expectCommands(
             ExpectShell(workdir='wkdir',
-                        command='"%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="Win32" /maxcpucount /t:"pj"',
+                        command='"%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="Win32" /maxcpucount /t:"pj"',  # noqa pylint: disable=line-too-long
                         env={'VCENV_BAT': r'${VS110COMNTOOLS}..\..\VC\vcvarsall.bat'})
             + 0
         )
@@ -808,7 +823,7 @@ class TestMsBuild(steps.BuildStepMixin, unittest.TestCase):
 
         self.expectCommands(
             ExpectShell(workdir='wkdir',
-                        command='"%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="x64" /maxcpucount /t:Rebuild',
+                        command='"%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="x64" /maxcpucount /t:Rebuild',  # noqa pylint: disable=line-too-long
                         env={'VCENV_BAT': r'${VS110COMNTOOLS}..\..\VC\vcvarsall.bat'})
             + 0
         )
