@@ -63,11 +63,12 @@ class GitMixin:
                 logname))
 
         if self.sshHostKey is not None and self.sshKnownHosts is not None:
-            config.error('{}: only one of sshPrivateKey and sshHostKey can be provided'.format(
+            config.error('{}: only one of sshKnownHosts and sshHostKey can be provided'.format(
                 logname))
 
         self.gitInstalled = False
         self.supportsBranch = False
+        self.supportsProgress = False
         self.supportsSubmoduleForce = False
         self.supportsSubmoduleCheckout = False
         self.supportsSshPrivateKeyAsEnvOption = False
@@ -86,6 +87,8 @@ class GitMixin:
         self.gitInstalled = True
         if LooseVersion(version) >= LooseVersion("1.6.5"):
             self.supportsBranch = True
+        if LooseVersion(version) >= LooseVersion("1.7.2"):
+            self.supportsProgress = True
         if LooseVersion(version) >= LooseVersion("1.7.6"):
             self.supportsSubmoduleForce = True
         if LooseVersion(version) >= LooseVersion("1.7.8"):
@@ -199,7 +202,7 @@ class GitStepMixin(GitMixin):
         if self.config is not None:
             for name, value in self.config.items():
                 full_command.append('-c')
-                full_command.append('%s=%s' % (name, value))
+                full_command.append('{}={}'.format(name, value))
 
         if self._isSshPrivateKeyNeededForGitCommand(command):
             self._adjustCommandParamsForSshPrivateKey(full_command, full_env)
@@ -212,8 +215,8 @@ class GitStepMixin(GitMixin):
 
         # If possible prefer to send a SIGTERM to git before we send a SIGKILL.
         # If we send a SIGKILL, git is prone to leaving around stale lockfiles.
-        # By priming it with a SIGTERM first we can ensure that it has a chance to shut-down gracefully
-        # before getting terminated
+        # By priming it with a SIGTERM first we can ensure that it has a chance to shut-down
+        # gracefully before getting terminated
         if not self.workerVersionIsOlderThan("shell", "2.16"):
             # git should shut-down quickly on SIGTERM.  If it doesn't don't let it
             # stick around for too long because this is on top of any timeout
@@ -243,7 +246,7 @@ class GitStepMixin(GitMixin):
         yield self.runCommand(cmd)
 
         if abandonOnFailure and cmd.didFail():
-            log.msg("Source step failed while running command %s" % cmd)
+            log.msg("Source step failed while running command {}".format(cmd))
             raise buildstep.BuildStepFailed()
         if collectStdout:
             return cmd.stdout
