@@ -61,11 +61,10 @@ class IndexResource(resource.Resource):
         res = {}
         allowed_ext = [".html"]
         try:
-            import pyjade
+            import pyjade   # pylint: disable=import-outside-toplevel
             allowed_ext.append(".jade")
         except ImportError:  # pragma: no cover
-            log.msg("pyjade not installed. Ignoring .jade files from %s" %
-                    (template_dir,))
+            log.msg("pyjade not installed. Ignoring .jade files from {}".format(template_dir))
             pyjade = None
         for root, dirs, files in os.walk(template_dir):
             if root == template_dir:
@@ -91,15 +90,15 @@ class IndexResource(resource.Resource):
                         compiler = pyjade.ext.html.Compiler(
                             block, pretty=False)
                         html = compiler.compile()
-                res[template_name % (basename,)] = json.dumps(html)
+                res[template_name % (basename,)] = html
 
         return res
 
     @staticmethod
     def getEnvironmentVersions():
-        import sys
-        import twisted
-        from buildbot import version as bbversion
+        import sys   # pylint: disable=import-outside-toplevel
+        import twisted   # pylint: disable=import-outside-toplevel
+        from buildbot import version as bbversion   # pylint: disable=import-outside-toplevel
 
         pyversion = '.'.join(map(str, sys.version_info[:3]))
 
@@ -118,7 +117,7 @@ class IndexResource(resource.Resource):
     def renderIndex(self, request):
         config = {}
         request.setHeader(b"content-type", b'text/html')
-        request.setHeader(b"Cache-Control", b"public;max-age=0")
+        request.setHeader(b"Cache-Control", b"public,max-age=0")
 
         try:
             yield self.config['auth'].maybeAutoLogin(request)
