@@ -86,7 +86,7 @@ class RestRootResource(resource.Resource):
     def render(self, request):
         request.setHeader(b"content-type", JSON_ENCODED)
         min_vers = self.master.config.www.get('rest_minimum_version', 0)
-        api_versions = dict(('v%d' % v, '%sapi/v%d' % (self.base_url, v))
+        api_versions = dict(('v{}'.format(v), '{}api/v{}'.format(self.base_url, v))
                             for v in self.version_classes
                             if v > min_vers)
         data = json.dumps(dict(api_versions=api_versions))
@@ -179,8 +179,7 @@ class V2RootResource(resource.Resource):
         try:
             data = json.loads(bytes2unicode(request.content.read()))
         except Exception as e:
-            raise BadJsonRpc2("JSON parse error: %s" % (str(e),),
-                              JSONRPC_CODES["parse_error"])
+            raise BadJsonRpc2("JSON parse error: {}".format(str(e)), JSONRPC_CODES["parse_error"])
 
         if isinstance(data, list):
             raise BadJsonRpc2("JSONRPC batch requests are not supported",
@@ -191,10 +190,9 @@ class V2RootResource(resource.Resource):
 
         def check(name, types, typename):
             if name not in data:
-                raise BadJsonRpc2("missing key '%s'" % (name,),
-                                  JSONRPC_CODES["invalid_request"])
+                raise BadJsonRpc2("missing key '{}'".format(name), JSONRPC_CODES["invalid_request"])
             if not isinstance(data[name], types):
-                raise BadJsonRpc2("'%s' must be %s" % (name, typename),
+                raise BadJsonRpc2("'{}' must be {}".format(name, typename),
                                   JSONRPC_CODES["invalid_request"])
         check("jsonrpc", (str,), "a string")
         check("method", (str,), "a string")
@@ -215,7 +213,7 @@ class V2RootResource(resource.Resource):
             if isinstance(msg, bytes):
                 msg = bytes2unicode(msg)
             if self.debug:
-                log.msg("JSONRPC error: %s" % (msg,))
+                log.msg("JSONRPC error: {}".format(msg))
             request.setResponseCode(errcode)
             request.setHeader(b'content-type', JSON_ENCODED)
             if "error" not in jsonRpcReply:  # already filled in by caller
@@ -269,23 +267,19 @@ class V2RootResource(resource.Resource):
             if arg == b'order':
                 order = tuple([bytes2unicode(o) for o in reqArgs[arg]])
                 checkFields(order, True)
-                continue
             elif arg == b'field':
                 fields = reqArgs[arg]
                 checkFields(fields, False)
-                continue
             elif arg == b'limit':
                 try:
                     limit = int(reqArgs[arg][0])
                 except Exception:
                     raise BadRequest('invalid limit')
-                continue
             elif arg == b'offset':
                 try:
                     offset = int(reqArgs[arg][0])
                 except Exception:
                     raise BadRequest('invalid offset')
-                continue
             elif arg == b'property':
                 try:
                     props = []
@@ -298,7 +292,6 @@ class V2RootResource(resource.Resource):
                     raise BadRequest(
                         'invalid property value for {}'.format(arg))
                 properties.append(resultspec.Property(arg, 'eq', props))
-                continue
             elif argStr in entityType.fieldNames:
                 field = entityType.fields[argStr]
                 try:
@@ -308,7 +301,6 @@ class V2RootResource(resource.Resource):
                         'invalid filter value for {}'.format(argStr))
 
                 filters.append(resultspec.Filter(argStr, 'eq', values))
-                continue
             elif '__' in argStr:
                 field, op = argStr.rsplit('__', 1)
                 args = reqArgs[arg]
@@ -324,9 +316,9 @@ class V2RootResource(resource.Resource):
                         raise BadRequest(
                             'invalid filter value for {}'.format(argStr))
                     filters.append(resultspec.Filter(field, op, values))
-                    continue
-            raise BadRequest(
-                "unrecognized query parameter '{}'".format(argStr))
+            else:
+                raise BadRequest(
+                    "unrecognized query parameter '{}'".format(argStr))
 
         # if ordering or filtering is on a field that's not in fields, bail out
         if fields:
@@ -361,7 +353,7 @@ class V2RootResource(resource.Resource):
     def renderRest(self, request):
         def writeError(msg, errcode=404, jsonrpccode=None):
             if self.debug:
-                log.msg("REST error: %s" % (msg,))
+                log.msg("REST error: {}".format(msg))
             request.setResponseCode(errcode)
             request.setHeader(b'content-type', b'text/plain; charset=utf-8')
             msg = bytes2unicode(msg)
@@ -466,7 +458,7 @@ class V2RootResource(resource.Resource):
         def writeError(msg, errcode=400):
             msg = bytes2unicode(msg)
             if self.debug:
-                log.msg("HTTP error: %s" % (msg,))
+                log.msg("HTTP error: {}".format(msg))
             request.setResponseCode(errcode)
             request.setHeader(b'content-type', b'text/plain; charset=utf-8')
             if request.method == b'POST':
